@@ -50,6 +50,7 @@
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
+#include <wsutil/array.h>
 
 /* forward reference */
 void proto_register_2dparityfec(void);
@@ -78,7 +79,7 @@ static int hf_2dparityfec_ts_pro_mpeg_ext;
 static int hf_2dparityfec_ts_recovery;
 static int hf_2dparityfec_type;
 
-static gint ett_2dparityfec;
+static int ett_2dparityfec;
 
 static const value_string fec_type_names[] = {
    {0, "XOR"},
@@ -89,22 +90,22 @@ static const value_string fec_type_names[] = {
 
 static int dissect_2dparityfec(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-   guint8   OffsetField;
-   guint8   NAField;
-   guint32  SNBase;
-   guint8   D;
+   uint8_t  OffsetField;
+   uint8_t  NAField;
+   uint32_t SNBase;
+   uint8_t  D;
 
    /* Extract SNBase */
-   SNBase  = (guint32)tvb_get_guint8(tvb, 0)<<8;
-   SNBase |= (guint32)tvb_get_guint8(tvb, 1);
-   SNBase |= (guint32)tvb_get_guint8(tvb, 15)<<16;
+   SNBase  = (uint32_t)tvb_get_uint8(tvb, 0)<<8;
+   SNBase |= (uint32_t)tvb_get_uint8(tvb, 1);
+   SNBase |= (uint32_t)tvb_get_uint8(tvb, 15)<<16;
 
    /* Extract D */
-   D = (tvb_get_guint8(tvb, 12)>>6) & 0x1;
+   D = (tvb_get_uint8(tvb, 12)>>6) & 0x1;
 
    /* Extract Offset and NA */
-   OffsetField    = tvb_get_guint8(tvb, 13);
-   NAField        = tvb_get_guint8(tvb, 14);
+   OffsetField    = tvb_get_uint8(tvb, 13);
+   NAField        = tvb_get_uint8(tvb, 14);
 
    col_set_str(pinfo->cinfo, COL_PROTOCOL, "2dFEC");
 
@@ -125,7 +126,7 @@ static int dissect_2dparityfec(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
       /* we are being asked for details */
       proto_item *ti;
       proto_tree *tree_2dparityfec;
-      gint offset = 0;
+      int offset = 0;
 
       ti = proto_tree_add_item(tree, proto_2dparityfec, tvb, 0, -1, ENC_NA);
       tree_2dparityfec = proto_item_add_subtree(ti, ett_2dparityfec);
@@ -225,7 +226,7 @@ void proto_register_2dparityfec(void)
    };
 
 /* Setup protocol subtree array */
-   static gint *ett[] = {
+   static int *ett[] = {
       &ett_2dparityfec,
    };
 
