@@ -569,7 +569,7 @@ dissect_njack(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
 
 	packet_type = tvb_get_uint8(tvb, 5);
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_SHORT_NAME);
-	col_add_str(pinfo->cinfo, COL_INFO, val_to_str(packet_type, njack_type_vals, "Type 0x%02x"));
+	col_add_str(pinfo->cinfo, COL_INFO, val_to_str(pinfo->pool, packet_type, njack_type_vals, "Type 0x%02x"));
 
 	ti = proto_tree_add_item(tree, proto_njack, tvb, offset, -1,
 				 ENC_NA);
@@ -603,7 +603,7 @@ dissect_njack(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
 				    1, ENC_BIG_ENDIAN);
 		offset += 1;
 		col_append_fstr(pinfo->cinfo, COL_INFO, ": %s",
-				val_to_str(setresult, njack_setresult_vals, "[0x%02x]"));
+				val_to_str(pinfo->pool, setresult, njack_setresult_vals, "[0x%02x]"));
 		break;
 	case NJACK_TYPE_GET:
 		/* Type 0x0b: S -> M, Magic, type, 00 00 63 ff */
