@@ -7,19 +7,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /*
@@ -29,7 +17,7 @@
  * Information was drawn from:
  *   ?
  *
- * It uses Ether ID 0x08ff which is not not officially registered.
+ * It uses Ether ID 0x08ff which is not officially registered.
  *
  */
 
@@ -51,10 +39,10 @@ static dissector_handle_t ax25_handle;
 
 static capture_dissector_handle_t ax25_cap_handle;
 
-static int proto_bpq            = -1;
-static int hf_bpq_len		= -1;
+static int proto_bpq;
+static int hf_bpq_len;
 
-static gint ett_bpq = -1;
+static int ett_bpq;
 
 static int
 dissect_bpq( tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void* data _U_ )
@@ -62,7 +50,7 @@ dissect_bpq( tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void* d
 	proto_item *ti;
 	proto_tree *bpq_tree;
 	int	    offset;
-	guint16	    bpq_len;
+	uint16_t	    bpq_len;
 	tvbuff_t   *next_tvb;
 
 
@@ -102,13 +90,13 @@ dissect_bpq( tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void* d
 	return tvb_captured_length(tvb);
 }
 
-static gboolean
-capture_bpq( const guchar *pd, int offset, int len, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header)
+static bool
+capture_bpq( const unsigned char *pd, int offset, int len, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header)
 {
 	int l_offset;
 
 	if ( ! BYTES_ARE_IN_FRAME( offset, len, BPQ_HEADER_SIZE ) )
-		return FALSE;
+		return false;
 
 	l_offset = offset;
 	l_offset += BPQ_HEADER_SIZE; /* step over bpq header to point at the AX.25 packet*/
@@ -128,7 +116,7 @@ proto_register_bpq(void)
 	};
 
 	/* Setup protocol subtree array */
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_bpq,
 	};
 
@@ -159,7 +147,7 @@ proto_reg_handoff_bpq(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
