@@ -21,19 +21,19 @@
 void proto_register_ftserver (void);
 void proto_reg_handoff_ftserver (void);
 
-static int proto_ftserver = -1;
-static int hf_ftserver_opnum = -1;
+static int proto_ftserver;
+static int hf_ftserver_opnum;
 
 
 
-static gint ett_ftserver = -1;
+static int ett_ftserver;
 
 
 static e_guid_t uuid_ftserver = { 0x4d37f2dd, 0xed43, 0x0004, { 0x02, 0xc0, 0x37, 0xcf, 0x1e, 0x00, 0x00, 0x00 } };
-static guint16  ver_ftserver = 4;
+static uint16_t ver_ftserver = 4;
 
 
-static dcerpc_sub_dissector ftserver_dissectors[] = {
+static const dcerpc_sub_dissector ftserver_dissectors[] = {
 	{  0, "CreateTrans",         NULL, NULL },
 	{  1, "AbortTrans",          NULL, NULL },
 	{  2, "DeleteTrans",         NULL, NULL },
@@ -67,7 +67,7 @@ proto_register_ftserver (void)
 	      NULL, 0x0, NULL, HFILL }}
 	};
 
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_ftserver,
 	};
 	proto_ftserver = proto_register_protocol ("FTServer Operations", "FTSERVER", "ftserver");
