@@ -28,7 +28,7 @@ void proto_register_ethertype(void);
 
 static dissector_table_t ethertype_dissector_table;
 
-static int proto_ethertype = -1;
+static int proto_ethertype;
 
 const value_string etype_vals[] = {
 	{ ETHERTYPE_IP,                   "IPv4" },
@@ -79,10 +79,11 @@ const value_string etype_vals[] = {
 	{ ETHERTYPE_MRP,                  "MRP" },
 	{ ETHERTYPE_IEEE_802_1AD,         "802.1ad Provider Bridge (Q-in-Q)" },
 	{ ETHERTYPE_MACSEC,               "802.1AE (MACsec)" },
-	{ ETHERTYPE_IEEE_1905,            "1905.1a Convergent Digital Home Network for Heterogenous Technologies" },
+	{ ETHERTYPE_IEEE_1905,            "1905.1a Convergent Digital Home Network for Heterogeneous Technologies" },
 	{ ETHERTYPE_IEEE_802_1AH,         "802.1ah Provider Backbone Bridge (mac-in-mac)" },
 	{ ETHERTYPE_IEEE_802_1BR,         "802.1br Bridge Port Extension E-Tag" },
 	{ ETHERTYPE_EAPOL,                "802.1X Authentication" },
+	{ ETHERTYPE_FORTINET_FGCP_HB,     "Fortinet FGCP (FortiGate Cluster Protocol) HB (HeartBeat)" },
 	{ ETHERTYPE_RSN_PREAUTH,          "802.11i Pre-Authentication" },
 	{ ETHERTYPE_MPLS,                 "MPLS label switched packet" },
 	{ ETHERTYPE_MPLS_MULTI,           "MPLS multicast label switched packet" },
@@ -158,7 +159,7 @@ const value_string etype_vals[] = {
 	{ PPP_PAP,                        "PPP Password Authentication Protocol" },
 	{ PPP_CCP,                        "PPP Compression Control Protocol" },
 	{ ETHERTYPE_LLT,                  "Veritas Low Latency Transport (not officially registered)" },
-	{ ETHERTYPE_CFM,                  "IEEE 802.1ag Connectivity Fault Management (CFM) protocol" },
+	{ ETHERTYPE_CFM,                  "IEEE 802.1Q Connectivity Fault Management (CFM) protocol" },
 	{ ETHERTYPE_DCE,                  "Data Center Ethernet (DCE) protocol(Cisco)" },
 	{ ETHERTYPE_FCOE,                 "Fibre Channel over Ethernet" },
 	{ ETHERTYPE_IEEE80211_DATA_ENCAP, "IEEE 802.11 data encapsulation" },
@@ -183,35 +184,37 @@ const value_string etype_vals[] = {
 	{ ETHERTYPE_NWP,                  "Neighborhood Watch Protocol" },
 	{ ETHERTYPE_BLUECOM,              "bluecom Protocol" },
 	{ ETHERTYPE_QINQ_OLD,             "QinQ: old non-standard 802.1ad" },
-	{ ETHERTYPE_TECMP,                "Technically Enhanced Capture Module Protocol (TECMP)" },
+	{ ETHERTYPE_TECMP,                "Technically Enhanced Capture Module Protocol (TECMP) or ASAM Capture Module Protocol (CMP)" },
 	{ ETHERTYPE_6LOWPAN,              "6LoWPAN" },
-	{ ETHERTYPE_AVSP,                 "Arista Timestamp" },
+	{ ETHERTYPE_AVSP,                 "Arista Vendor Specific Protocol" },
 	{ ETHERTYPE_ECPRI,                "eCPRI" },
 	{ ETHERTYPE_CABLELABS,            "CableLabs Layer-3 Protocol" },
 	{ ETHERTYPE_EXEH,                 "EXos internal Extra Header" },
+	{ ETHERTYPE_ATMF,                 "Allied Telesis Autonomous Management Framework" },
+	{ ETHERTYPE_ATRL,                 "Allied Telesis Resiliency Link" },
 	{ ETHERTYPE_ACIGLEAN,             "Cisco ACI ARP gleaning" },
 	{ ETHERTYPE_IEEE_802_1CB,         "802.1CB Frame Replication and Elimination for Reliability" },
 	{ 0, NULL }
 };
 
-static void eth_prompt(packet_info *pinfo, gchar* result)
+static void eth_prompt(packet_info *pinfo, char* result)
 {
 	snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "Ethertype 0x%04x as",
 		GPOINTER_TO_UINT(p_get_proto_data(pinfo->pool, pinfo, proto_ethertype, pinfo->curr_layer_num)));
 }
 
-static gpointer eth_value(packet_info *pinfo)
+static void *eth_value(packet_info *pinfo)
 {
 	return p_get_proto_data(pinfo->pool, pinfo, proto_ethertype, pinfo->curr_layer_num);
 }
 
 static void add_dix_trailer(packet_info *pinfo, proto_tree *tree, proto_tree *fh_tree,
 			    int trailer_id, tvbuff_t *tvb, tvbuff_t *next_tvb, int offset_after_etype,
-			    guint length_before, gint fcs_len);
+			    unsigned length_before, int fcs_len);
 
 /*
 void
-ethertype(guint16 etype, tvbuff_t *tvb, int offset_after_etype,
+ethertype(uint16_t etype, tvbuff_t *tvb, int offset_after_etype,
 	  packet_info *pinfo, proto_tree *tree, proto_tree *fh_tree,
 	  int etype_id, int trailer_id, int fcs_len)
 */
@@ -220,8 +223,8 @@ dissect_ethertype(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
 {
 	const char	  *description;
 	tvbuff_t	  *volatile next_tvb;
-	guint		   length_before;
-	gint		   captured_length, reported_length;
+	unsigned		   length_before;
+	int		   captured_length, reported_length;
 	volatile int	   dissector_found = 0;
 	const char	  *volatile saved_proto;
 	ethertype_data_t  *ethertype_data;
@@ -240,25 +243,25 @@ dissect_ethertype(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
 	/* With Cisco ACI gleaning, the rest of the packet is dissected for informational purposes only */
 	if (ethertype_data->etype == ETHERTYPE_ACIGLEAN) {
 
-		guint gleantype, payload_etype;
+		unsigned gleantype, payload_etype;
 
 		col_add_fstr(pinfo->cinfo, COL_PROTOCOL, "0x%04x", ethertype_data->etype);
-		col_set_writable(pinfo->cinfo, COL_PROTOCOL, FALSE);
+		col_set_writable(pinfo->cinfo, COL_PROTOCOL, false);
 
 		description = try_val_to_str(ethertype_data->etype, etype_vals);
 		col_add_str(pinfo->cinfo, COL_INFO, description);
-		col_set_writable(pinfo->cinfo, COL_INFO, FALSE);
+		col_set_writable(pinfo->cinfo, COL_INFO, false);
 		if (reported_length >= 1) {
-			gleantype = (tvb_get_guint8(tvb, ethertype_data->payload_offset) & 0xF0) >> 4;
+			gleantype = (tvb_get_uint8(tvb, ethertype_data->payload_offset) & 0xF0) >> 4;
 			switch (gleantype) {
 			case 4: /* IPv4 */
-				payload_etype = 0x0800;
+				payload_etype = ETHERTYPE_IP;
 				break;
 			case 6: /* IPv6 */
-				payload_etype = 0x86BB;
+				payload_etype = ETHERTYPE_IPv6;
 				break;
 			default: /* ARP */
-				payload_etype = 0x0806;
+				payload_etype = ETHERTYPE_ARP;
 			}
 			ethertype_data->etype = payload_etype;
 		// FIXME: Add glean to protocol-stack in frame-header
@@ -285,7 +288,7 @@ dissect_ethertype(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
 	next_tvb = tvb_new_subset_length_caplen(tvb, ethertype_data->payload_offset, captured_length,
 				  reported_length);
 
-	p_add_proto_data(pinfo->pool, pinfo, proto_ethertype, pinfo->curr_layer_num, GUINT_TO_POINTER((guint)ethertype_data->etype));
+	p_add_proto_data(pinfo->pool, pinfo, proto_ethertype, pinfo->curr_layer_num, GUINT_TO_POINTER((unsigned)ethertype_data->etype));
 
 	/* Look for sub-dissector, and call it if found.
 	   Catch exceptions, so that if the reported length of "next_tvb"
@@ -337,9 +340,9 @@ dissect_ethertype(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
 static void
 add_dix_trailer(packet_info *pinfo, proto_tree *tree, proto_tree *fh_tree, int trailer_id,
 		tvbuff_t *tvb, tvbuff_t *next_tvb, int offset_after_etype,
-		guint length_before, gint fcs_len)
+		unsigned length_before, int fcs_len)
 {
-	guint		 length;
+	unsigned		 length;
 	tvbuff_t	*trailer_tvb;
 
 	/* OK, how much is there in that tvbuff now? */
@@ -367,7 +370,41 @@ add_dix_trailer(packet_info *pinfo, proto_tree *tree, proto_tree *fh_tree, int t
 	} else
 		trailer_tvb = NULL;	/* no trailer */
 
-	add_ethernet_trailer(pinfo, tree, fh_tree, trailer_id, tvb, trailer_tvb, fcs_len);
+	/* XXX: If the length of next_tvb is less than it was before, but this
+	 * is not the first time the ethertype dissector has been called, we
+	 * would rather not add the trailer here, but instead also reduce the
+	 * length of tvb and have the previous ethertype dissector add the
+	 * trailer instead. That's the only way we can properly detect and
+	 * check the FCS in "maybefcs" mode (we need the full frame.)
+	 * It also would be less confusing because we would always just
+	 * use eth.trailer instead of sometimes e.g. vlan.trailer (#18252).
+	 *
+	 * It does require that the second time the ethertype dissector was
+	 * called that ethertype_data.payload_offset was set and the original
+	 * tvb used instead of creating a new subset tvb - in the latter case
+	 * tvb here is not the same as the next_tvb from the previous ethertype
+	 * dissector. That's not the case for ethertypes like 802.1AE MACSec
+	 * that add a trailer as well, where we likely took a subset to shave
+	 * off the trailer.
+	 *
+	 * We can't just "set the reported length of the backing tvbuff",
+	 * because the ultimately backing tvbuff might be something that
+	 * encapsulates the Ethernet frame, e.g. ISL or GSE Bridged Frames)
+	 *
+	 * To see if the ethertype dissector was called earlier from the entire
+	 * Ethernet frame, we can't just check if offset_after_etype != 14, as
+	 * it could be something that calls ethertype directly without having the
+	 * entire Ethernet frame somewhere (e.g. a Linux "cooked mode" capture
+	 * (packet-sll), or something set in the USER ENCAP UAT, etc.)
+	 * We also can't check pinfo->curr_proto_layer_num or proto_layers if
+	 * there are multiple entire Ethernet frames encapsulated in this
+	 * frame, e.g. a DVB BaseBand Frame with multiple GSE frames with
+	 * Bridge Frame encapsulation.
+	 *
+	 * We might need to add a new field to ethertype_data, or set
+	 * something in pinfo->pool scoped packet data.
+	 */
+	add_ethernet_trailer(pinfo, tree, fh_tree, trailer_id, tvb, trailer_tvb, fcs_len, offset_after_etype);
 }
 
 void
