@@ -7,6 +7,8 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
+ * https://www.iana.org/assignments/ftp-commands-extensions/ftp-commands-extensions.xhtml
+ *
  * Copied from packet-pop.c
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -207,9 +209,13 @@ uint32_t eo_row_count;
  * was completely captured. It might be possible to infer a successful
  * transfer with either the "SIZE" command or with a 226 response code
  * (indicating that the STOR or RETR command was successful), but there
- * is no guarantee that either of these are present. As such, this
- * implementation takes a best-effort approach of simply appending
- * all associated ftp-data packets to the export objects entry.
+ * is no guarantee that either of these are present. Similarly, an ALLOcate
+ * command could indicate the expected length, a RESTart indicates that
+ * the one entry isn't a full file, an APPEnd indicates that the entry might
+ * or might not be a full file, and the response to a STOUnique is necessary
+ * to know what the file name is on the receiving side, as opposed to on the
+ * sending side. This implementation takes a best-effort approach of simply
+ * appending all associated ftp-data packets to the export objects entry.
  */
 static tap_packet_status
 ftp_eo_packet(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_, const void *data, tap_flags_t flags _U_)
@@ -218,8 +224,12 @@ ftp_eo_packet(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_, const
     const ftp_eo_t *eo_info = (const ftp_eo_t *)data;
 
     if(eo_info) { /* We have data waiting for us */
-        /* Only export files transferred with STOR or RETR*/
-        if (strncmp(eo_info->command, "STOR", 4) != 0 && strncmp(eo_info->command, "RETR", 4) != 0) {
+        /* Only export files transferred, not directory listings. */
+        if (strncmp(eo_info->command, "STOR", 4) != 0 &&
+            strncmp(eo_info->command, "RETR", 4) != 0 &&
+            strncmp(eo_info->command, "STOU", 4) != 0 &&
+            strncmp(eo_info->command, "APPE", 4) != 0) {
+
             return TAP_PACKET_DONT_REDRAW; /* State unchanged - no window updates needed */
         }
         /* Create the command_packet_to_eo_row hashtable for mapping the FTP
@@ -407,6 +417,19 @@ static void create_and_link_data_conversation(packet_info *pinfo,
     p_ftp_conv->current_data_setup_frame = pinfo->num;
 }
 
+static bool
+cmd_resp_is_data(const char *cmd)
+{
+    /* These are the commands which send a response on a data connection. */
+    return (strncmp(cmd, "RETR", 4) == 0 ||
+        strncmp(cmd, "STOR", 4) == 0 ||
+        strncmp(cmd, "STOU", 4) == 0 ||
+        strncmp(cmd, "APPE", 4) == 0 ||
+        strncmp(cmd, "LIST", 4) == 0 ||
+        strncmp(cmd, "NLST", 4) == 0 ||
+        strncmp(cmd, "MLSD", 4) == 0);
+}
+
 /********************************************************************/
 
 
@@ -463,7 +486,7 @@ static void create_and_link_data_conversation(packet_info *pinfo,
  * the address and port number.
  */
 static bool
-parse_port_pasv(tvbuff_t *tvb, int offset, int linelen, uint32_t *ftp_ip,
+parse_port_pasv(tvbuff_t *tvb, packet_info* pinfo, int offset, int linelen, uint32_t *ftp_ip,
     uint16_t *ftp_port, uint32_t *pasv_offset, unsigned *ftp_ip_len,
     unsigned *ftp_port_len)
 {
@@ -477,7 +500,7 @@ parse_port_pasv(tvbuff_t *tvb, int offset, int linelen, uint32_t *ftp_ip,
     /*
      * Copy the rest of the line into a null-terminated buffer.
      */
-    args = wmem_alloc(wmem_packet_scope(), linelen + 1);
+    args = wmem_alloc(pinfo->pool, linelen + 1);
     tvb_get_raw_bytes_as_string(tvb, offset, args, linelen + 1);
     p = args;
 
@@ -573,7 +596,7 @@ isvalid_rfc2428_delimiter(const unsigned char c)
  *
  */
 static bool
-parse_eprt_request(tvbuff_t *tvb, int offset, int linelen, uint32_t *eprt_af,
+parse_eprt_request(tvbuff_t *tvb, packet_info* pinfo, int offset, int linelen, uint32_t *eprt_af,
         uint32_t *eprt_ip, uint16_t *eprt_ipv6, uint16_t *ftp_port,
         uint32_t *eprt_ip_len, uint32_t *ftp_port_len)
 {
@@ -592,7 +615,7 @@ parse_eprt_request(tvbuff_t *tvb, int offset, int linelen, uint32_t *eprt_af,
         return false;
 
     /* Copy the rest of the line into a null-terminated buffer. */
-    args = wmem_alloc(wmem_packet_scope(), linelen + 1);
+    args = wmem_alloc(pinfo->pool, linelen + 1);
     tvb_get_raw_bytes_as_string(tvb, offset, args, linelen + 1);
     p = args;
     /*
@@ -646,13 +669,13 @@ parse_eprt_request(tvbuff_t *tvb, int offset, int linelen, uint32_t *eprt_af,
 
         if (delimiters_seen == 2) {     /* end of address family field */
             char *af_str;
-            af_str = wmem_strndup(wmem_packet_scope(), field, fieldlen);
+            af_str = wmem_strndup(pinfo->pool, field, fieldlen);
             if (!ws_strtou32(af_str, NULL, eprt_af))
                 return false;
         }
         else if (delimiters_seen == 3) {/* end of IP address field */
             char *ip_str;
-            ip_str = wmem_strndup(wmem_packet_scope(), field, fieldlen);
+            ip_str = wmem_strndup(pinfo->pool, field, fieldlen);
 
             if (*eprt_af == EPRT_AF_IPv4) {
                 if (str_to_ip(ip_str, eprt_ip))
@@ -673,7 +696,7 @@ parse_eprt_request(tvbuff_t *tvb, int offset, int linelen, uint32_t *eprt_af,
         }
         else if (delimiters_seen == 4) {/* end of port field */
             char *pt_str;
-            pt_str = wmem_strndup(wmem_packet_scope(), field, fieldlen);
+            pt_str = wmem_strndup(pinfo->pool, field, fieldlen);
 
             if (!ws_strtou16(pt_str, NULL, ftp_port))
                 return false;
@@ -709,7 +732,7 @@ parse_eprt_request(tvbuff_t *tvb, int offset, int linelen, uint32_t *eprt_af,
  *
  */
 static bool
-parse_extended_pasv_response(tvbuff_t *tvb, int offset, int linelen,
+parse_extended_pasv_response(tvbuff_t *tvb, packet_info* pinfo, int offset, int linelen,
         uint16_t *ftp_port, unsigned *pasv_offset, unsigned *ftp_port_len)
 {
     int        n;
@@ -723,7 +746,7 @@ parse_extended_pasv_response(tvbuff_t *tvb, int offset, int linelen,
     /*
      * Copy the rest of the line into a null-terminated buffer.
      */
-    args = wmem_alloc(wmem_packet_scope(), linelen + 1);
+    args = wmem_alloc(pinfo->pool, linelen + 1);
     tvb_get_raw_bytes_as_string(tvb, offset, args, linelen + 1);
     p = args;
 
@@ -843,9 +866,9 @@ static bool begins_with_separator(wmem_strbuf_t *path)
 
 /* Add new_path to the current working directory of the conversation, then normalise. */
 /* N.B. could use e.g. g_build_path() here, but doesn't really buy us anything */
-static void add_directory_to_conv(ftp_conversation_t *conv, const char *new_path)
+static void add_directory_to_conv(ftp_conversation_t *conv, const char *new_path, packet_info* pinfo)
 {
-    wmem_strbuf_t *appended_path = wmem_strbuf_new(wmem_packet_scope(), NULL);
+    wmem_strbuf_t *appended_path = wmem_strbuf_new(pinfo->pool, NULL);
 
     if (!wmem_strbuf_get_len(conv->current_working_directory)) {
         /* Currently empty so just assign to new */
@@ -867,7 +890,7 @@ static void add_directory_to_conv(ftp_conversation_t *conv, const char *new_path
 
     /* Initialise with empty path */
     wmem_strbuf_t *normalised_directory = wmem_strbuf_new(wmem_file_scope(), NULL);
-    wmem_strbuf_t *this_folder = wmem_strbuf_new(wmem_packet_scope(), NULL);
+    wmem_strbuf_t *this_folder = wmem_strbuf_new(pinfo->pool, NULL);
 
     offset = 0;
     /* If absolute, add root to this one too */
@@ -909,7 +932,7 @@ static void add_directory_to_conv(ftp_conversation_t *conv, const char *new_path
                 }
 
                 /* Reset folder name for next time */
-                this_folder = wmem_strbuf_new(wmem_packet_scope(), NULL);
+                this_folder = wmem_strbuf_new(pinfo->pool, NULL);
             }
         }
         else {
@@ -927,7 +950,7 @@ static void add_directory_to_conv(ftp_conversation_t *conv, const char *new_path
 }
 
 /* In response to the arg to a CWD command succeeding, update the conversation's current working directory */
-static void process_cwd_success(ftp_conversation_t *conv, const char *new_path)
+static void process_cwd_success(ftp_conversation_t *conv, const char *new_path, packet_info* pinfo)
 {
     if (g_path_is_absolute(new_path)) {
         /* Just adopt new_path */
@@ -935,7 +958,7 @@ static void process_cwd_success(ftp_conversation_t *conv, const char *new_path)
     }
     else {
         /* Add new_path to what we already have */
-        add_directory_to_conv(conv, new_path);
+        add_directory_to_conv(conv, new_path, pinfo);
     }
 }
 
@@ -1134,13 +1157,13 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                 }
             } else if (tvb_strneql(tvb, 0, "PASS", tokenlen) == 0) {
                 if (p_ftp_conv && p_ftp_conv->username) {
-                    tap_credential_t* auth = wmem_new0(wmem_packet_scope(), tap_credential_t);
+                    tap_credential_t* auth = wmem_new0(pinfo->pool, tap_credential_t);
                     auth->num = pinfo->num;
                     auth->proto = "FTP";
                     auth->password_hf_id = hf_ftp_request_arg;
                     auth->username = p_ftp_conv->username;
                     auth->username_num = p_ftp_conv->username_pkt_num;
-                    auth->info = wmem_strdup_printf(wmem_packet_scope(), "Username in packet: %u", p_ftp_conv->username_pkt_num);
+                    auth->info = wmem_strdup_printf(pinfo->pool, "Username in packet: %u", p_ftp_conv->username_pkt_num);
                     tap_queue_packet(credentials_tap, pinfo, auth);
                 }
             }
@@ -1156,16 +1179,26 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                 p_ftp_conv->tls_requested = true;
         }
         /* And make sure set for FTP data conversation */
-        if (p_ftp_conv && p_ftp_conv->current_data_conv && !p_ftp_conv->current_data_conv->command) {
-            /* Store command and frame where it happened */
-            p_ftp_conv->current_data_conv->command = tvb_get_string_enc(wmem_file_scope(), tvb, 0, linelen, ENC_UTF_8);
-            p_ftp_conv->current_data_conv->command_frame = pinfo->num;
+        if (p_ftp_conv && p_ftp_conv->current_data_conv && !PINFO_FD_VISITED(pinfo)) {
+            /* Only certain commands send their responses on the data
+             * connection. If we haven't gotten a command at all though,
+             * save it as better than nothing. It will be replaced by a
+             * later command if present.
+             */
+            if (!p_ftp_conv->current_data_conv->command ||
+                (!cmd_resp_is_data(p_ftp_conv->current_data_conv->command) &&
+                  cmd_resp_is_data(p_ftp_conv->last_command))) {
 
-            /* Add to table to ftp-data response can be shown with this frame on later passes */
-            g_hash_table_insert(ftp_command_to_data_hash, GUINT_TO_POINTER(pinfo->num),
-                                p_ftp_conv->current_data_conv);
-            g_hash_table_insert(ftp_command_to_data_hash, GUINT_TO_POINTER(p_ftp_conv->current_data_setup_frame),
-                                p_ftp_conv->current_data_conv);
+                /* Store command and frame where it happened */
+                p_ftp_conv->current_data_conv->command = tvb_get_string_enc(wmem_file_scope(), tvb, 0, linelen, ENC_UTF_8);
+                p_ftp_conv->current_data_conv->command_frame = pinfo->num;
+
+                /* Add to table so ftp-data response can be shown with this frame on later passes */
+                g_hash_table_insert(ftp_command_to_data_hash, GUINT_TO_POINTER(pinfo->num),
+                                    p_ftp_conv->current_data_conv);
+                g_hash_table_insert(ftp_command_to_data_hash, GUINT_TO_POINTER(p_ftp_conv->current_data_setup_frame),
+                                    p_ftp_conv->current_data_conv);
+            }
         }
     } else {
         /*
@@ -1231,13 +1264,13 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                     if (p_ftp_conv && p_ftp_conv->last_command) {
                         /* Explicit Change Working Directory command */
                         if (strncmp(p_ftp_conv->last_command, "CWD ", 4) == 0) {
-                            process_cwd_success(p_ftp_conv, p_ftp_conv->last_command+4);
+                            process_cwd_success(p_ftp_conv, p_ftp_conv->last_command+4, pinfo);
                             /* Update path in packet */
                             store_directory_in_packet(pinfo, p_ftp_conv);
                         }
                         /* Change Directory Up command (i.e. "CWD ..") */
                         else if (strncmp(p_ftp_conv->last_command, "CDUP", 4) == 0) {
-                            process_cwd_success(p_ftp_conv, "..");
+                            process_cwd_success(p_ftp_conv, "..", pinfo);
                             /* Update path in packet */
                             store_directory_in_packet(pinfo, p_ftp_conv);
                         }
@@ -1303,7 +1336,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
      * If this is a PORT request or a PASV response, handle it.
      */
     if (is_port_request) {
-        if (parse_port_pasv(tvb, offset, linelen, &ftp_ip, &ftp_port, &pasv_offset, &ftp_ip_len, &ftp_port_len)) {
+        if (parse_port_pasv(tvb, pinfo, offset, linelen, &ftp_ip, &ftp_port, &pasv_offset, &ftp_ip_len, &ftp_port_len)) {
             proto_tree_add_ipv4(reqresp_tree, hf_ftp_active_ip,
                     tvb, pasv_offset + (tokenlen+1) , ftp_ip_len, ftp_ip);
             proto_tree_add_uint(reqresp_tree, hf_ftp_active_port,
@@ -1329,7 +1362,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
              * This frame contains a PASV response; set up a
              * conversation for the data.
              */
-            if (parse_port_pasv(tvb, offset, linelen, &pasv_ip, &ftp_port, &pasv_offset, &ftp_ip_len, &ftp_port_len)) {
+            if (parse_port_pasv(tvb, pinfo, offset, linelen, &pasv_ip, &ftp_port, &pasv_offset, &ftp_ip_len, &ftp_port_len)) {
                 proto_tree_add_ipv4(reqresp_tree, hf_ftp_pasv_ip,
                         tvb, pasv_offset + 4, ftp_ip_len, pasv_ip);
                 proto_tree_add_uint(reqresp_tree, hf_ftp_pasv_port,
@@ -1353,7 +1386,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
          * This frame contains a EPRT request; let's dissect it and set up a
          * conversation for the data connection.
          */
-        if (parse_eprt_request(tvb, offset, linelen,
+        if (parse_eprt_request(tvb, pinfo, offset, linelen,
                     &eprt_af, &eprt_ip, eprt_ipv6, &ftp_port,
                     &eprt_ip_len, &ftp_port_len)) {
 
@@ -1400,7 +1433,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
              * This frame contains an  EPSV response; set up a
              * conversation for the data.
              */
-            if (parse_extended_pasv_response(tvb, offset, linelen,
+            if (parse_extended_pasv_response(tvb, pinfo, offset, linelen,
                         &ftp_port, &pasv_offset, &ftp_port_len)) {
                 /* Add IP address and port number to tree */
 
@@ -1609,11 +1642,11 @@ dissect_ftpdata(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
             }
             if (have_tap_listener(ftp_eo_tap)) {
                 if (p_ftp_data_conv->command_frame) {
-                    ftp_eo_t *eo_info = wmem_new0(wmem_packet_scope(), ftp_eo_t);
-                    eo_info->command = wmem_strdup(wmem_packet_scope(), p_ftp_data_conv->command);
+                    ftp_eo_t *eo_info = wmem_new0(pinfo->pool, ftp_eo_t);
+                    eo_info->command = wmem_strdup(pinfo->pool, p_ftp_data_conv->command);
                     eo_info->command_frame = p_ftp_data_conv->command_frame;
                     eo_info->payload_len = tvb_reported_length(tvb);
-                    eo_info->payload_data = (char *) tvb_memdup(wmem_packet_scope(), tvb, 0, tvb_reported_length(tvb));
+                    eo_info->payload_data = (char *) tvb_memdup(pinfo->pool, tvb, 0, tvb_reported_length(tvb));
                     tap_queue_packet(ftp_eo_tap, pinfo, eo_info);
                 }
             }
@@ -1697,7 +1730,7 @@ proto_register_ftp(void)
 
         { &hf_ftp_pasv_port,
           { "Passive port", "ftp.passive.port",
-            FT_UINT16, BASE_DEC, NULL,0x0,
+            FT_UINT16, BASE_PT_TCP, NULL,0x0,
             "Passive FTP server port", HFILL }},
 
         { &hf_ftp_pasv_nat,
@@ -1712,7 +1745,7 @@ proto_register_ftp(void)
 
         { &hf_ftp_active_port,
           {"Active port", "ftp.active.port",
-           FT_UINT16, BASE_DEC, NULL, 0x0,
+           FT_UINT16, BASE_PT_TCP, NULL, 0x0,
            "Active FTP client port", HFILL }},
 
         { &hf_ftp_active_nat,
@@ -1737,7 +1770,7 @@ proto_register_ftp(void)
 
         { &hf_ftp_eprt_port,
           { "Extended active port", "ftp.eprt.port",
-            FT_UINT16, BASE_DEC, NULL, 0,
+            FT_UINT16, BASE_PT_TCP, NULL, 0,
             "Extended active FTP client listener port", HFILL }},
 
         { &hf_ftp_epsv_ip,
@@ -1752,7 +1785,7 @@ proto_register_ftp(void)
 
         { &hf_ftp_epsv_port,
           { "Extended passive port", "ftp.epsv.port",
-            FT_UINT16, BASE_DEC, NULL, 0,
+            FT_UINT16, BASE_PT_TCP, NULL, 0,
             "Extended passive FTP server port", HFILL }},
 
         { &hf_ftp_command_response_first_frame_num,
