@@ -1,6 +1,9 @@
 /* packet-geneve.c
  * Routines for Geneve - Generic Network Virtualization Encapsulation
- * https://tools.ietf.org/html/draft-ietf-nvo3-geneve
+ * https://tools.ietf.org/html/rfc8926
+ *
+ * Copyright (c) 2024 cPacket Networks, Inc. All Rights Reserved.
+ * Author: Martin Greenberg <mgreenberg@cpacket.com>
  *
  * Copyright (c) 2014 VMware, Inc. All Rights Reserved.
  * Author: Jesse Gross <jesse@nicira.com>
@@ -20,7 +23,6 @@
 #include <epan/packet.h>
 #include <epan/etypes.h>
 #include <epan/expert.h>
-#include <epan/value_string.h>
 #include <epan/tfs.h>
 #include <epan/unit_strings.h>
 
@@ -36,6 +38,8 @@
 #define OPT_FLAGS_SHIFT 5
 #define OPT_LEN_MASK 0x1F
 
+/* https://www.iana.org/assignments/nvo3/nvo3.xhtml#geneve-option-class last update 2024-12-20 */
+
 static const range_string class_id_names[] = {
     { 0, 0xFF, "Standard" },
     { 0x0100, 0x0100, "Linux" },
@@ -53,7 +57,22 @@ static const range_string class_id_names[] = {
     { 0x0130, 0x0131, "Cisco Systems, Inc." },
     { 0x0132, 0x0135, "Google LLC" },
     { 0x0136, 0x0136, "InfoQuick Global Connection Tech Ltd." },
-    { 0x0137, 0xFEFF, "Unassigned" },
+    { 0x0137, 0x0140, "Alibaba, inc" },
+    { 0x0141, 0x0144, "Palo Alto Networks" },
+    { 0x0145, 0x0149, "Huawei Technologies Co., Ltd" },
+    { 0x014A, 0x014A, "EMnify GmbH" },
+    { 0x014B, 0x014B, "Cilium" },
+    { 0x014C, 0x014C, "Corelight, Inc." },
+    { 0x014D, 0x014D, "1NCE GmbH" },
+    { 0x014E, 0x0157, "Cloud of China Telecom (CTYUN)" },
+    { 0x0158, 0x0161, "Volcengine, inc" },
+    { 0x0162, 0x0162, "nat64.net" },
+    { 0x0163, 0x0163, "Multi Segment SD-WAN" },
+    { 0x0164, 0x0164, "cPacket Networks, Inc." },
+    { 0x0165, 0x0167, "Tencent" },
+    { 0x0168, 0x0168, "ExtraHop Networks, Inc." },
+    { 0x0169, 0x0169, "Soosan INT Co., Ltd." },
+    { 0x016A, 0xFEFF, "Unassigned" },
     { 0xFFF0, 0xFFFF, "Experimental" },
     { 0, 0, NULL }
 };
@@ -61,11 +80,15 @@ static const range_string class_id_names[] = {
 #define GENEVE_GCP_VNID     0x013201
 #define GENEVE_GCP_ENDPOINT 0x013202
 #define GENEVE_GCP_PROFILE  0x013203
+#define GENEVE_CILIUM_SERVICE   0x014B81
+#define GENEVE_CPACKET_METADATA  0x016400
 
 static const val64_string option_names[] = {
   { GENEVE_GCP_VNID,     "GCP Virtual Network ID" },
   { GENEVE_GCP_ENDPOINT, "GCP Endpoint ID" },
   { GENEVE_GCP_PROFILE,  "GCP Profile ID" },
+  { GENEVE_CILIUM_SERVICE,    "Cilium Service IP" },
+  { GENEVE_CPACKET_METADATA,  "cPacket Meta-data" },
   { 0, NULL }
 };
 
@@ -97,6 +120,21 @@ static int hf_geneve_opt_gcp_reserved;
 static int hf_geneve_opt_gcp_direction;
 static int hf_geneve_opt_gcp_endpoint;
 static int hf_geneve_opt_gcp_profile;
+static int hf_geneve_opt_cilium_service_ipv4;
+static int hf_geneve_opt_cilium_service_ipv6;
+static int hf_geneve_opt_cilium_service_port;
+static int hf_geneve_opt_cilium_service_pad;
+static int hf_geneve_opt_cpkt_seqnum;
+static int hf_geneve_opt_cpkt_origlen;
+static int hf_geneve_opt_cpkt_reserved;
+static int hf_geneve_opt_cpkt_timestamp;
+static int hf_geneve_opt_cpkt_ts_sec;
+static int hf_geneve_opt_cpkt_ts_nsec;
+static int hf_geneve_opt_cpkt_ts_fracns;
+static int hf_geneve_opt_cpkt_version;
+static int hf_geneve_opt_cpkt_devid;
+static int hf_geneve_opt_cpkt_portid;
+
 static int hf_geneve_opt_unknown_data;
 
 static int ett_geneve;
@@ -181,9 +219,9 @@ dissect_option(wmem_allocator_t *scope, tvbuff_t *tvb, proto_tree *opts_tree, in
             proto_tree_add_bits_item(opt_tree, hf_geneve_opt_gcp_vnid, tvb, offset * 8,
                                      28, ENC_BIG_ENDIAN);
             proto_tree_add_item(opt_tree, hf_geneve_opt_gcp_direction, tvb, offset,
-                                4, ENC_NA);
+                                4, ENC_BIG_ENDIAN);
             proto_tree_add_item(opt_tree, hf_geneve_opt_gcp_reserved, tvb, offset,
-                                4, ENC_NA);
+                                4, ENC_BIG_ENDIAN);
             break;
         case GENEVE_GCP_ENDPOINT:
             proto_tree_add_item(opt_tree, hf_geneve_opt_gcp_endpoint, tvb, offset,
@@ -193,6 +231,68 @@ dissect_option(wmem_allocator_t *scope, tvbuff_t *tvb, proto_tree *opts_tree, in
             proto_tree_add_item(opt_tree, hf_geneve_opt_gcp_profile, tvb, offset,
                                 len - 4, ENC_BIG_ENDIAN);
             break;
+        case GENEVE_CILIUM_SERVICE:
+            switch (len) {
+                case 12: {
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_cilium_service_ipv4, tvb, offset,
+                                        4, ENC_BIG_ENDIAN);
+                    offset += 4;
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_cilium_service_port, tvb, offset,
+                                        2, ENC_BIG_ENDIAN);
+                    offset += 2;
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_cilium_service_pad, tvb, offset,
+                                        2, ENC_NA);
+                }
+                break;
+                case 24: {
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_cilium_service_ipv6, tvb, offset,
+                                        16, ENC_NA);
+                    offset += 16;
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_cilium_service_port, tvb, offset,
+                                        2, ENC_BIG_ENDIAN);
+                    offset += 2;
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_cilium_service_pad, tvb, offset,
+                                        2, ENC_NA);
+                }
+                break;
+                default:
+                    proto_tree_add_item(opt_tree, hf_geneve_opt_unknown_data, tvb, offset,
+                                        len - 4, ENC_NA);
+                break;
+            }
+            break;
+        case GENEVE_CPACKET_METADATA:
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_seqnum, tvb, offset,
+                                4, ENC_BIG_ENDIAN);
+            offset += 4;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_origlen, tvb, offset,
+                                2, ENC_BIG_ENDIAN);
+            offset += 2;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_reserved, tvb, offset,
+                                1, ENC_BIG_ENDIAN);
+            offset += 1;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_version, tvb, offset,
+                                1, ENC_BIG_ENDIAN);
+            offset += 1;
+            // PTPv2 timestamp has more resolution than NStime supports/displays,
+            // but parse appropriate subsection of into NStime for user convenience
+            proto_tree_add_time_item(opt_tree, hf_geneve_opt_cpkt_timestamp, tvb, offset+2, 8,
+                                     ENC_TIME_SECS_NSECS|ENC_BIG_ENDIAN, NULL, NULL, NULL);
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_ts_sec, tvb, offset,
+                                6, ENC_BIG_ENDIAN);
+            offset += 6;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_ts_nsec, tvb, offset,
+                                4, ENC_BIG_ENDIAN);
+            offset += 4;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_ts_fracns, tvb, offset,
+                                2, ENC_BIG_ENDIAN);
+            offset += 2;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_devid, tvb, offset,
+                                2, ENC_BIG_ENDIAN);
+            offset += 2;
+            proto_tree_add_item(opt_tree, hf_geneve_opt_cpkt_portid, tvb, offset,
+                                2, ENC_BIG_ENDIAN);
+            break;
         default:
             proto_tree_add_item(opt_tree, hf_geneve_opt_unknown_data, tvb, offset,
                                 len - 4, ENC_NA);
@@ -292,7 +392,7 @@ dissect_geneve(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 
     proto_type = tvb_get_ntohs(tvb, offset);
     col_add_fstr(pinfo->cinfo, COL_INFO, "Encapsulated %s",
-                 val_to_str(proto_type, etype_vals, "0x%04x (unknown)"));
+                 val_to_str(pinfo->pool, proto_type, etype_vals, "0x%04x (unknown)"));
 
     offset += 2;
 
@@ -436,6 +536,76 @@ proto_register_geneve(void)
             FT_UINT64, BASE_DEC, NULL, 0x00,
             NULL, HFILL }
         },
+        { &hf_geneve_opt_cilium_service_ipv4,
+          { "Cilium Service IPv4", "geneve.option.cilium.service.ipv4",
+            FT_IPv4, BASE_NONE, NULL, 0x00,
+            NULL, HFILL }
+        },
+        { &hf_geneve_opt_cilium_service_ipv6,
+          { "Cilium Service IPv6", "geneve.option.cilium.service.ipv6",
+            FT_IPv6, BASE_NONE, NULL, 0x00,
+            NULL, HFILL }
+        },
+        { &hf_geneve_opt_cilium_service_port,
+          { "Cilium Service Port", "geneve.option.cilium.service.port",
+            FT_UINT16, BASE_DEC, NULL, 0x00,
+            NULL, HFILL }
+        },
+        { &hf_geneve_opt_cilium_service_pad,
+          { "Pad", "geneve.option.cilium.service.pad",
+            FT_BYTES, BASE_NONE, NULL, 0x00,
+            NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_seqnum,
+         { "cPacket Packet ID", "geneve.option.cPacket.packetid",
+           FT_UINT32, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_origlen,
+         { "cPacket Original length", "geneve.option.cPacket.orig_len",
+           FT_UINT16, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_reserved,
+         { "cPacket Reserved", "geneve.option.cPacket.reserved",
+           FT_UINT8, BASE_HEX, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_version,
+         { "cPacket Metadata version", "geneve.option.cPacket.version",
+           FT_UINT8, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_timestamp,
+         { "cPacket Timestamp", "geneve.option.cPacket.timestamp",
+           FT_ABSOLUTE_TIME, ABSOLUTE_TIME_UTC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_ts_sec,
+         { "cPacket Timestamp (s)", "geneve.option.cPacket.ts_sec",
+           FT_UINT48, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_ts_nsec,
+         { "cPacket Timestamp (ns)", "geneve.option.cPacket.ts_nsec",
+           FT_UINT32, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_ts_fracns,
+         { "cPacket Timestamp (frac. ns)", "geneve.option.cPacket.ts_fracns",
+           FT_UINT16, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_devid,
+         { "cPacket Device ID", "geneve.option.cPacket.device_id",
+           FT_UINT16, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
+        { &hf_geneve_opt_cpkt_portid,
+         { "cPacket Port ID", "geneve.option.cPacket.port_id",
+           FT_UINT16, BASE_DEC, NULL, 0x00,
+           NULL, HFILL }
+        },
         { &hf_geneve_opt_unknown_data,
           { "Unknown Option Data", "geneve.option.unknown.data",
             FT_BYTES, BASE_NONE, NULL, 0x00,
