@@ -180,8 +180,8 @@ dissect_gsmrlp_xid(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree
 	int cur;
 
 	for (cur = offset; cur < (int) tvb_reported_length(tvb);) {
-		uint8_t len = tvb_get_guint8(tvb, cur) & 0x0f;
-		uint8_t type = tvb_get_guint8(tvb, cur) >> 4;
+		uint8_t len = tvb_get_uint8(tvb, cur) & 0x0f;
+		uint8_t type = tvb_get_uint8(tvb, cur) >> 4;
 		proto_tree *xid_tree;
 
 		proto_tree_add_subtree_format(tree, tvb, cur, 1 + len, ett_gsmrlp_xid, &xid_tree, "XID Parameter: %s",
@@ -212,8 +212,8 @@ dissect_gsmrlp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "GSM-RLP");
 
-	n_s = (tvb_get_guint8(tvb, 0)) >> 3 | ((tvb_get_guint8(tvb, 1) & 1) << 5);
-	n_r = (tvb_get_guint8(tvb, 1) >> 2);
+	n_s = (tvb_get_uint8(tvb, 0)) >> 3 | ((tvb_get_uint8(tvb, 1) & 1) << 5);
+	n_r = (tvb_get_uint8(tvb, 1) >> 2);
 
 	ti = proto_tree_add_protocol_format(tree, proto_gsmrlp, tvb, 0, reported_len,
 					    "GSM RLP");
@@ -227,14 +227,14 @@ dissect_gsmrlp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 		proto_tree_add_item_ret_uint(rlp_tree, hf_gsmrlp_u_ftype, tvb, 1, 1, ENC_BIG_ENDIAN, &u_ftype);
 		if ((n_r & 0x1f) == RLP_U_FT_XID)
 			dissect_gsmrlp_xid(tvb, 2, pinfo, rlp_tree);
-		proto_item_append_text(ti, " U-Frame: %s", val_to_str(u_ftype, rlp_ftype_u_vals, "Unknown 0x%02x"));
+		proto_item_append_text(ti, " U-Frame: %s", val_to_str(pinfo->pool, u_ftype, rlp_ftype_u_vals, "Unknown 0x%02x"));
 	} else if (n_s == 0x3e) { /* S Frame */
 		unsigned s_ftype;
 		proto_tree_add_uint(rlp_tree, hf_gsmrlp_ftype, tvb, 0, 1, RLP_FT_S);
 		proto_tree_add_item_ret_uint(rlp_tree, hf_gsmrlp_s_ftype, tvb, 0, 1, ENC_BIG_ENDIAN, &s_ftype);
 		proto_tree_add_uint(rlp_tree, hf_gsmrlp_n_r, tvb, 1, 1, n_r);
 		proto_item_append_text(ti, " S-Frame: %s, N(S): %u, N(R): %u",
-				       val_to_str(s_ftype, rlp_ftype_s_vals, "Unknown 0x%02x"), n_s, n_r);
+				       val_to_str(pinfo->pool, s_ftype, rlp_ftype_s_vals, "Unknown 0x%02x"), n_s, n_r);
 	} else { /* IS Frame */
 		tvbuff_t *next_tvb;
 		unsigned s_ftype;
@@ -245,7 +245,7 @@ dissect_gsmrlp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 		proto_tree_add_uint(rlp_tree, hf_gsmrlp_n_s, tvb, 0, 2, n_s);
 		proto_tree_add_uint(rlp_tree, hf_gsmrlp_n_r, tvb, 1, 1, n_r);
 		proto_item_append_text(ti, " IS-Frame: %s, N(S): %u, N(R): %u",
-				       val_to_str(s_ftype, rlp_ftype_s_vals, "Unknown 0x%02x"), n_s, n_r);
+				       val_to_str(pinfo->pool, s_ftype, rlp_ftype_s_vals, "Unknown 0x%02x"), n_s, n_r);
 
 		/* dispatch user data */
 		data_len = reported_len - 2 /* header */ - 3 /* FCS */;
