@@ -14,10 +14,11 @@
 #include <epan/exceptions.h>
 #include <epan/show_exception.h>
 #include <epan/capture_dissectors.h>
+#include <epan/tfs.h>
+#include <wsutil/array.h>
 
 #include "packet-isl.h"
 #include "packet-eth.h"
-#include "packet-tr.h"
 
 void proto_register_isl(void);
 void proto_reg_handoff_isl(void);
@@ -98,7 +99,6 @@ capture_isl(const unsigned char *pd, int offset, int len, capture_packet_info_t
   case TYPE_TR:
     offset += 14+17;    /* skip the header */
     return call_capture_dissector(tr_cap_handle, pd, offset, len, cpinfo, pseudo_header);
-    break;
   }
 
   return false;
