@@ -286,7 +286,7 @@ static const value_string mint_0x22_tlv_vals[] = {
 
 static int
 dissect_eth_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mint_tree,
-	volatile guint32 offset, guint32 length)
+	volatile uint32_t offset, uint32_t length)
 {
 	tvbuff_t *eth_tvb;
 
@@ -311,24 +311,24 @@ dissect_eth_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mint_tree,
 
 static int
 dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-	guint32 offset, guint32 packet_length, guint received_via)
+	uint32_t offset, uint32_t packet_length, unsigned received_via)
 {
 	proto_item *ti;
 	proto_tree *mint_tree = NULL;
 	proto_tree *mint_header_tree = NULL;
 	proto_tree *mint_data_tree = NULL;
 	proto_tree *mint_ctrl_tree = NULL;
-	guint16 bytes_remaining;
-	guint16 mint_port;
-	guint8 type, length, header_length;
-	guint32 message_type;
-	guint8 element_length;
+	uint16_t bytes_remaining;
+	uint16_t mint_port;
+	uint8_t type, length, header_length;
+	uint32_t message_type;
+	uint8_t element_length;
 	int hf_tlv_vals;
 
 	mint_port = tvb_get_ntohs(tvb, offset + 12);
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_SHORT_NAME);
-	col_add_str(pinfo->cinfo, COL_INFO, val_to_str(mint_port,
+	col_add_str(pinfo->cinfo, COL_INFO, val_to_str(pinfo->pool, mint_port,
 		mint_port_vals, "Type %03d"));
 
 	ti = proto_tree_add_item(tree, proto_mint, tvb,
@@ -387,7 +387,7 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			offset, 2, ENC_BIG_ENDIAN);
 		offset += 2;
 		proto_tree_add_item(mint_data_tree, hf_mint_data_seqno, tvb,
-			offset, 4, ENC_NA);
+			offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		proto_tree_add_item(mint_data_tree, hf_mint_data_unknown1, tvb,
 			offset, 4, ENC_NA);
@@ -414,7 +414,7 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		proto_tree_add_item(mint_ctrl_tree, hf_mint_router_unknown3, tvb,
 			offset, 1, ENC_NA);
 		offset += 1;
-		header_length = tvb_get_guint8(tvb, offset);
+		header_length = tvb_get_uint8(tvb, offset);
 		proto_tree_add_item(mint_ctrl_tree, hf_mint_router_header_length, tvb,
 			offset, 1, ENC_NA);
 		offset += 1;
@@ -453,17 +453,17 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			offset += header_length - 12;
 		}
 		while (offset < packet_length - 2) {
-			type = tvb_get_guint8(tvb, offset);
+			type = tvb_get_uint8(tvb, offset);
 			proto_tree_add_item(mint_ctrl_tree, hf_tlv_vals, tvb,
 				offset, 1, ENC_NA);
 			offset += 1;
-			length = tvb_get_guint8(tvb, offset);
+			length = tvb_get_uint8(tvb, offset);
 			/* FIXME: This is a hack - reliable array detection missing */
 			if (type == 1 && length == 128) {
 				proto_tree_add_item(mint_ctrl_tree, hf_mint_router_array, tvb,
 					offset, 1, ENC_NA);
 				offset += 1;
-				length = tvb_get_guint8(tvb, offset);
+				length = tvb_get_uint8(tvb, offset);
 			}
 			proto_tree_add_item(mint_ctrl_tree, hf_mint_router_length, tvb,
 				offset, 1, ENC_NA);
@@ -473,7 +473,7 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 				break;
 			}
 			if (type == 1 && element_length) {
-				guint32 end_offset = offset + length;
+				uint32_t end_offset = offset + length;
 				for (; offset < end_offset; offset += element_length) {
 					proto_tree_add_item(mint_ctrl_tree, hf_mint_router_element, tvb,
 						offset, element_length, ENC_NA);
@@ -511,7 +511,7 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			proto_tree_add_item(mint_ctrl_tree, hf_mint_mlcp_type, tvb,
 				offset, 1, ENC_NA);
 			offset += 1;
-			length = tvb_get_guint8(tvb, offset);
+			length = tvb_get_uint8(tvb, offset);
 			proto_tree_add_item(mint_ctrl_tree, hf_mint_mlcp_length, tvb,
 				offset, 1, ENC_NA);
 			offset += 1;
@@ -543,11 +543,11 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		break;
 	}
 #if defined MINT_DEVELOPMENT
-	tree_expanded_set(ett_mint, TRUE);
-	tree_expanded_set(ett_mint_ethshim, TRUE);
-	tree_expanded_set(ett_mint_header, TRUE);
-	tree_expanded_set(ett_mint_ctrl, TRUE);
-	tree_expanded_set(ett_mint_data, TRUE);
+	tree_expanded_set(ett_mint, true);
+	tree_expanded_set(ett_mint_ethshim, true);
+	tree_expanded_set(ett_mint_header, true);
+	tree_expanded_set(ett_mint_ctrl, true);
+	tree_expanded_set(ett_mint_data, true);
 #endif
 	return offset;
 }
@@ -555,7 +555,7 @@ dissect_mint_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 static int
 dissect_mint_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	guint32 packet_length = tvb_captured_length(tvb);
+	uint32_t packet_length = tvb_captured_length(tvb);
 
 	return dissect_mint_common(tvb, pinfo, tree, 0, packet_length,
 		PORT_MINT_CONTROL_TUNNEL);
@@ -564,7 +564,7 @@ dissect_mint_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 static int
 dissect_mint_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	guint32 packet_length = tvb_captured_length(tvb);
+	uint32_t packet_length = tvb_captured_length(tvb);
 
 	return dissect_mint_common(tvb, pinfo, tree, 0, packet_length,
 		PORT_MINT_DATA_TUNNEL);
@@ -575,8 +575,8 @@ dissect_mint_ethshim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_item *ti;
 	proto_tree *mint_ethshim_tree = NULL;
-	guint32 offset = 0;
-	guint32 packet_length;
+	uint32_t offset = 0;
+	uint32_t packet_length;
 
 	ti = proto_tree_add_item(tree, hf_mint_ethshim, tvb,
 		offset, 4, ENC_NA);
@@ -595,52 +595,52 @@ dissect_mint_ethshim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	return offset;
 }
 
-static gboolean
+static bool
 test_mint_control(tvbuff_t *tvb _U_)
 {
 #if 0
 	/* Minimum of 8 bytes, first byte (version) has value of 3 */
 	if ( tvb_length(tvb) < 8
-		    || tvb_get_guint8(tvb, 0) != 3
-		    /* || tvb_get_guint8(tvb, 2) != 0
+		    || tvb_get_uint8(tvb, 0) != 3
+		    /* || tvb_get_uint8(tvb, 2) != 0
 		    || tvb_get_ntohs(tvb, 6) > tvb_reported_length(tvb) */
 	) {
-		return FALSE;
+		return false;
 	}
 #endif
-	return TRUE;
+	return true;
 }
 
-static gboolean
+static bool
 test_mint_data(tvbuff_t *tvb _U_)
 {
 #if 0
 	/* Minimum of 8 bytes, first byte (version) has value of 3 */
 	if ( tvb_length(tvb) < 8
-		    || tvb_get_guint8(tvb, 0) != 3
-		    /* || tvb_get_guint8(tvb, 2) != 0
+		    || tvb_get_uint8(tvb, 0) != 3
+		    /* || tvb_get_uint8(tvb, 2) != 0
 		    || tvb_get_ntohs(tvb, 6) > tvb_reported_length(tvb) */
 	) {
-		return FALSE;
+		return false;
 	}
 #endif
-	return TRUE;
+	return true;
 }
 
-static gboolean
+static bool
 test_mint_eth(tvbuff_t *tvb _U_)
 {
 #if 0
 	/* Minimum of 8 bytes, first byte (version) has value of 3 */
 	if ( tvb_length(tvb) < 8
-		    || tvb_get_guint8(tvb, 0) != 3
-		    /* || tvb_get_guint8(tvb, 2) != 0
+		    || tvb_get_uint8(tvb, 0) != 3
+		    /* || tvb_get_uint8(tvb, 2) != 0
 		    || tvb_get_ntohs(tvb, 6) > tvb_reported_length(tvb) */
 	) {
-		return FALSE;
+		return false;
 	}
 #endif
-	return TRUE;
+	return true;
 }
 
 static int
@@ -871,7 +871,7 @@ proto_register_mint(void)
 		},
 	};
 
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_mint_ethshim,
 		&ett_mint,
 		&ett_mint_header,
