@@ -108,8 +108,8 @@ static int hf_sccpmg_smi;
 static int hf_sccpmg_congestion_level;
 
 /* Initialize the subtree pointers */
-static gint ett_sccpmg;
-static gint ett_sccpmg_affected_pc;
+static int ett_sccpmg;
+static int ett_sccpmg_affected_pc;
 
 static expert_field ei_sccpmg_unknown_msg;
 
@@ -122,9 +122,9 @@ dissect_sccpmg_affected_ssn(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 }
 
 static void
-dissect_sccpmg_affected_pc(tvbuff_t *tvb, proto_tree *sccpmg_tree)
+dissect_sccpmg_affected_pc(tvbuff_t *tvb, packet_info* pinfo, proto_tree *sccpmg_tree)
 {
-	gint offset = SCCPMG_AFFECTED_PC_OFFSET;
+	int offset = SCCPMG_AFFECTED_PC_OFFSET;
 
 	if (mtp3_standard == ITU_STANDARD) {
 		proto_tree_add_item(sccpmg_tree, hf_sccpmg_affected_itu_pc, tvb,
@@ -143,7 +143,7 @@ dissect_sccpmg_affected_pc(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 		}
 
 		/* create and fill the PC tree */
-		dissect_mtp3_3byte_pc(tvb, offset, sccpmg_tree,
+		dissect_mtp3_3byte_pc(tvb, pinfo, offset, sccpmg_tree,
 				      ett_sccpmg_affected_pc, *hf_affected_pc,
 				      hf_sccpmg_affected_pc_network,
 				      hf_sccpmg_affected_pc_cluster,
@@ -155,7 +155,7 @@ dissect_sccpmg_affected_pc(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 static void
 dissect_sccpmg_smi(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 {
-	gint offset = 0;
+	int offset = 0;
 
 	if (mtp3_standard == ITU_STANDARD || mtp3_standard == JAPAN_STANDARD)
 		offset = ITU_SCCPMG_SMI_OFFSET;
@@ -169,7 +169,7 @@ dissect_sccpmg_smi(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 static void
 dissect_sccpmg_congestion_level(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 {
-	gint offset = 0;
+	int offset = 0;
 
 	if (mtp3_standard == CHINESE_ITU_STANDARD)
 		offset = CHINESE_ITU_SCCPMG_CONGESTION_OFFSET;
@@ -183,10 +183,10 @@ dissect_sccpmg_congestion_level(tvbuff_t *tvb, proto_tree *sccpmg_tree)
 static void
 dissect_sccpmg_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *sccpmg_tree)
 {
-	guint8 message_type;
+	uint8_t message_type;
 
 	/* Extract the message type;  all other processing is based on this */
-	message_type   = tvb_get_guint8(tvb, SCCPMG_MESSAGE_TYPE_OFFSET);
+	message_type   = tvb_get_uint8(tvb, SCCPMG_MESSAGE_TYPE_OFFSET);
 
 	col_add_fstr(pinfo->cinfo, COL_INFO, "%s ", val_to_str_const(message_type, sccpmg_message_type_acro_values, "Unknown"));
 
@@ -213,7 +213,7 @@ dissect_sccpmg_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *sccpmg_tre
 	case SCCPMG_MESSAGE_TYPE_SOR:
 	case SCCPMG_MESSAGE_TYPE_SOG:
 		dissect_sccpmg_affected_ssn(tvb, sccpmg_tree);
-		dissect_sccpmg_affected_pc(tvb, sccpmg_tree);
+		dissect_sccpmg_affected_pc(tvb, pinfo, sccpmg_tree);
 		dissect_sccpmg_smi(tvb, sccpmg_tree);
 
 		break;
@@ -221,7 +221,7 @@ dissect_sccpmg_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *sccpmg_tre
 		if (mtp3_standard != ANSI_STANDARD)
 		{
 			dissect_sccpmg_affected_ssn(tvb, sccpmg_tree);
-			dissect_sccpmg_affected_pc(tvb, sccpmg_tree);
+			dissect_sccpmg_affected_pc(tvb, pinfo, sccpmg_tree);
 			dissect_sccpmg_smi(tvb, sccpmg_tree);
 			dissect_sccpmg_congestion_level(tvb, sccpmg_tree);
 		}
@@ -318,7 +318,7 @@ proto_register_sccpmg(void)
 	};
 
 	/* Setup protocol subtree array */
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_sccpmg,
 		&ett_sccpmg_affected_pc
 	};
