@@ -12,10 +12,21 @@ def pytest_addoption(parser):
     parser.addoption('--disable-capture', action='store_true',
         help='Disable capture tests'
     )
-    parser.addoption('--program-path', help='Path to Wireshark executables.')
+    parser.addoption('--disable-gui', action='store_true',
+        help='Disable GUI tests'
+    )
+    parser.addoption('--build-type', default='RelWithDebInfo',
+        help='CMake build type for multi-config generators.'
+    )
+    parser.addoption('--program-path',
+        help='Path to Wireshark executables.'
+    )
     parser.addoption('--skip-missing-programs',
         help='Skip tests that lack programs from this list instead of failing'
-             ' them. Use "all" to ignore all missing programs.')
+             ' them. Use "all" to ignore all missing programs.',
+        # We might want to build this automatically, e.g. by grepping CMakeCache.txt
+        default='stratoshark,strato,falcodump,sshdig'
+    )
     parser.addoption('--enable-release', action='store_true',
         help='Enable release tests'
     )
