@@ -13,7 +13,6 @@
 #include <string.h>
 
 #include "file.h"
-#include "frame_tvbuff.h"
 #include "ui/proto_hier_stats.h"
 #include "ui/progress_dlg.h"
 #include "epan/epan_dissect.h"
@@ -29,10 +28,10 @@
 static int pc_proto_id = -1;
 
     static GNode*
-find_stat_node(GNode *parent_stat_node, header_field_info *needle_hfinfo)
+find_stat_node(GNode *parent_stat_node, const header_field_info *needle_hfinfo)
 {
     GNode		*needle_stat_node, *up_parent_stat_node;
-    header_field_info	*hfinfo;
+    const header_field_info	*hfinfo;
     ph_stats_node_t	*stats;
 
     /* Look down the tree */
@@ -65,7 +64,7 @@ find_stat_node(GNode *parent_stat_node, header_field_info *needle_hfinfo)
     /* None found. Create one. */
     stats = g_new(ph_stats_node_t, 1);
 
-    /* Intialize counters */
+    /* Initialize counters */
     stats->hfinfo = needle_hfinfo;
     stats->num_pkts_total = 0;
     stats->num_pdus_total = 0;
@@ -79,8 +78,18 @@ find_stat_node(GNode *parent_stat_node, header_field_info *needle_hfinfo)
     return needle_stat_node;
 }
 
+static bool
+ph_node_is_proto(proto_node *ptree_node)
+{
+    if (!PNODE_FINFO(ptree_node))
+        return false;
 
-    static void
+    const header_field_info *hfinfo = PNODE_FINFO(ptree_node)->hfinfo;
+    return proto_registrar_is_protocol(hfinfo->id) && hfinfo->id != pc_proto_id;
+}
+
+static void
+// NOLINTNEXTLINE(misc-no-recursion)
 process_node(proto_node *ptree_node, GNode *parent_stat_node, ph_stats_t *ps)
 {
     field_info		*finfo;
@@ -90,8 +99,6 @@ process_node(proto_node *ptree_node, GNode *parent_stat_node, ph_stats_t *ps)
 
     finfo = PNODE_FINFO(ptree_node);
     /* We don't fake protocol nodes we expect them to have a field_info.
-     * Even with a faked proto tree, we don't fake nodes when PTREE_FINFO(tree)
-     * is NULL in order to avoid crashes here and elsewhere. (See epan/proto.c)
      */
     ws_assert(finfo);
 
@@ -121,11 +128,15 @@ process_node(proto_node *ptree_node, GNode *parent_stat_node, ph_stats_t *ps)
      * the tree to pick up embedded protocols not added to the toplevel of
      * the tree.
      */
-    while (proto_sibling_node && !proto_registrar_is_protocol(PNODE_FINFO(proto_sibling_node)->hfinfo->id)) {
+    while (proto_sibling_node) {
+        if (ph_node_is_proto(proto_sibling_node)) {
+            break;
+        }
         proto_sibling_node = proto_sibling_node->next;
     }
 
     if (proto_sibling_node) {
+        // We recurse here but we're limited by proto tree checks
         process_node(proto_sibling_node, stat_node, ps);
     } else {
         stats->num_pkts_last++;
@@ -146,7 +157,10 @@ process_tree(proto_tree *protocol_tree, ph_stats_t* ps)
      * "Packet comments" item that steals items from "Frame".
      */
     ptree_node = ((proto_node *)protocol_tree)->first_child;
-    while (ptree_node && (ptree_node->finfo->hfinfo->id == pc_proto_id || !proto_registrar_is_protocol(ptree_node->finfo->hfinfo->id))) {
+    while (ptree_node) {
+        if (ph_node_is_proto(ptree_node)) {
+            break;
+        }
         ptree_node = ptree_node->next;
     }
 
@@ -157,24 +171,22 @@ process_tree(proto_tree *protocol_tree, ph_stats_t* ps)
     process_node(ptree_node, ps->stats_tree, ps);
 }
 
-    static gboolean
+    static bool
 process_record(capture_file *cf, frame_data *frame, column_info *cinfo,
-               wtap_rec *rec, Buffer *buf, ph_stats_t* ps)
+               wtap_rec *rec, ph_stats_t* ps)
 {
     epan_dissect_t	edt;
     double		cur_time;
 
     /* Load the record from the capture file */
-    if (!cf_read_record(cf, frame, rec, buf))
-        return FALSE;	/* failure */
+    if (!cf_read_record(cf, frame, rec))
+        return false;	/* failure */
 
     /* Dissect the record   tree  not visible */
-    epan_dissect_init(&edt, cf->epan, TRUE, FALSE);
+    epan_dissect_init(&edt, cf->epan, true, false);
     /* Don't fake protocols. We need them for the protocol hierarchy */
-    epan_dissect_fake_protocols(&edt, FALSE);
-    epan_dissect_run(&edt, cf->cd_t, rec,
-                     frame_tvbuff_new_buffer(&cf->provider, frame, buf),
-                     frame, cinfo);
+    epan_dissect_fake_protocols(&edt, false);
+    epan_dissect_run(&edt, cf->cd_t, rec, frame, cinfo);
 
     /* Get stats from this protocol tree */
     process_tree(edt.tree, ps);
@@ -190,22 +202,22 @@ process_record(capture_file *cf, frame_data *frame, column_info *cinfo,
 
     /* Free our memory. */
     epan_dissect_cleanup(&edt);
+    wtap_rec_cleanup(rec);
 
-    return TRUE;	/* success */
+    return true;	/* success */
 }
 
     ph_stats_t*
 ph_stats_new(capture_file *cf)
 {
     ph_stats_t	*ps;
-    guint32	framenum;
+    uint32_t	framenum;
     frame_data	*frame;
     progdlg_t	*progbar = NULL;
     int		count;
     wtap_rec	rec;
-    Buffer	buf;
     float	progbar_val;
-    gchar	status_str[100];
+    char	status_str[100];
     int		progbar_nextstep;
     int		progbar_quantum;
 
@@ -215,9 +227,9 @@ ph_stats_new(capture_file *cf)
         ws_warning("Failing to compute protocol hierarchy stats on \"%s\" since a read is in progress", cf->filename);
         return NULL;
     }
-    cf->read_lock = TRUE;
+    cf->read_lock = true;
 
-    cf->stop_flag = FALSE;
+    cf->stop_flag = false;
 
     pc_proto_id = proto_registrar_get_id_byname("pkt_comment");
 
@@ -239,8 +251,7 @@ ph_stats_new(capture_file *cf)
     /* Progress so far. */
     progbar_val = 0.0f;
 
-    wtap_rec_init(&rec);
-    ws_buffer_init(&buf, 1514);
+    wtap_rec_init(&rec, 1514);
 
     for (framenum = 1; framenum <= cf->count; framenum++) {
         frame = frame_data_sequence_find(cf->provider.frames, framenum);
@@ -255,7 +266,7 @@ ph_stats_new(capture_file *cf)
             progbar = delayed_create_progress_dlg(
                     cf->window, "Computing",
                     "protocol hierarchy statistics",
-                    TRUE, &cf->stop_flag, progbar_val);
+                    true, &cf->stop_flag, progbar_val);
 
         /* Update the progress bar, but do it only N_PROGBAR_UPDATES
            times; when we update it, we have to run the GTK+ main
@@ -269,7 +280,7 @@ ph_stats_new(capture_file *cf)
              */
             ws_assert(cf->count > 0);
 
-            progbar_val = (gfloat) count / cf->count;
+            progbar_val = (float) count / cf->count;
 
             if (progbar != NULL) {
                 snprintf(status_str, sizeof(status_str),
@@ -309,13 +320,13 @@ ph_stats_new(capture_file *cf)
             ps->tot_packets++;
 
             /* we don't care about colinfo */
-            if (!process_record(cf, frame, NULL, &rec, &buf, ps)) {
+            if (!process_record(cf, frame, NULL, &rec, ps)) {
                 /*
                  * Give up, and set "stop_flag" so we
                  * just abort rather than popping up
                  * the statistics window.
                  */
-                cf->stop_flag = TRUE;
+                cf->stop_flag = true;
                 break;
             }
 
@@ -326,7 +337,6 @@ ph_stats_new(capture_file *cf)
     }
 
     wtap_rec_cleanup(&rec);
-    ws_buffer_free(&buf);
 
     /* We're done calculating the statistics; destroy the progress bar
        if it was created. */
@@ -344,17 +354,17 @@ ph_stats_new(capture_file *cf)
     }
 
     ws_assert(cf->read_lock);
-    cf->read_lock = FALSE;
+    cf->read_lock = false;
 
     return ps;
 }
 
     static gboolean
-stat_node_free(GNode *node, gpointer data _U_)
+stat_node_free(GNode *node, void *data _U_)
 {
     ph_stats_node_t	*stats = (ph_stats_node_t *)node->data;
     g_free(stats);
-    return FALSE;
+    return false;
 }
 
     void
