@@ -28,27 +28,21 @@ protected:
 
 public slots:
     bool checkFilter();
-    void applyDisplayFilter();
 
 private slots:
     void checkFilter(const QString &filter_text);
-    void clearFilter();
     void changeEvent(QEvent* event);
 
-    void showFilters();
-    void prepareFilter();
-
 private:
     QString placeholder_text_;
 
     void setDefaultPlaceholderText();
-    void buildCompletionList(const QString& field_word);
+    void buildCompletionList(const QString &field_word, const QString &preamble);
 
 signals:
     void pushFilterSyntaxStatus(const QString&);
     void popFilterSyntaxStatus();
     void pushFilterSyntaxWarning(const QString&);
-    void filterPackets(QString new_filter, bool force);
 };
 
 #endif // FIELDFILTEREDIT_H
