@@ -10,6 +10,8 @@
 #define WS_LOG_DOMAIN LOG_DOMAIN_WIRETAP
 #include "wtap-int.h"
 
+#include <assert.h>
+
 #include <string.h>
 #include <stdlib.h>
 
@@ -22,9 +24,12 @@
 #endif
 #include <wsutil/ws_assert.h>
 
+#include "wtap_module.h"
 #include "wtap_modules.h"
 #include "file_wrappers.h"
 #include "required_file_handlers.h"
+#include <wsutil/application_flavor.h>
+#include <wsutil/array.h>
 #include <wsutil/buffer.h>
 #include <wsutil/str_util.h>
 
@@ -94,7 +99,9 @@
 #include "autosar_dlt.h"
 #include "rtpdump.h"
 #include "ems.h"
-
+#include "ttl.h"
+#include "peak-trc.h"
+#include "netlog.h"
 
 /*
  * Add an extension, and all compressed versions thereof if requested,
@@ -139,9 +146,9 @@ add_extensions(GSList *extensions, const char *extension,
  * All added file types, regardless of extension or lack thereof,
  * must also be added open_info_base[] below.
  */
-static const struct file_extension_info file_type_extensions_base[] = {
+static const struct file_extension_info wireshark_file_type_extensions_base[] = {
 	{ "Wireshark/tcpdump/... - pcap", true, "pcap;cap;dmp" },
-	{ "Wireshark/... - pcapng", true, "pcapng;scap;ntar" },
+	{ "Wireshark/... - pcapng", true, "pcapng;ntar" },
 	{ "Network Monitor, Surveyor, NetScaler", true, "cap" },
 	{ "Sun snoop", true, "snoop" },
 	{ "InfoVista 5View capture", true, "5vw" },
@@ -170,16 +177,27 @@ static const struct file_extension_info file_type_extensions_base[] = {
 	{ "CAM Inspector file", true, "camins" },
 	{ "BLF file", true, "blf" },
 	{ "AUTOSAR DLT file", true, "dlt" },
+	{ "TTL file", true, "ttl" },
 	{ "MPEG files", false, "mpeg;mpg;mp3" },
 	{ "Transport-Neutral Encapsulation Format", false, "tnef" },
 	{ "JPEG/JFIF files", false, "jpg;jpeg;jfif" },
+	{ "NetLog file", true, "json" },
 	{ "JavaScript Object Notation file", false, "json" },
 	{ "MP4 file", false, "mp4" },
 	{ "RTPDump file", false, "rtp;rtpdump" },
 	{ "EMS file", false, "ems" },
+	{ "ASN.1 Basic Encoding Rules", false, "cer;crl;csr;p10;p12;p772;p7c;p7s;p7m;p8;pfx;tsq;tsr" },
+	{ "RFC 7468 files", false, "crt;pem" },
+	{ "PEAK CAN TRC log", true, "trc" },
 };
 
-#define	N_FILE_TYPE_EXTENSIONS	array_length(file_type_extensions_base)
+#define	N_WIRESHARK_FILE_TYPE_EXTENSIONS array_length(wireshark_file_type_extensions_base)
+
+static const struct file_extension_info stratoshark_file_type_extensions_base[] = {
+    {"Stratoshark/... - scap", true, "scap"},
+};
+
+#define N_STRATOSHARK_FILE_TYPE_EXTENSIONS array_length(stratoshark_file_type_extensions_base)
 
 static const struct file_extension_info* file_type_extensions;
 
@@ -194,7 +212,11 @@ init_file_type_extensions(void)
 
 	file_type_extensions_arr = g_array_new(false,true,sizeof(struct file_extension_info));
 
-	g_array_append_vals(file_type_extensions_arr,file_type_extensions_base,N_FILE_TYPE_EXTENSIONS);
+	if (application_flavor_is_wireshark()) {
+		g_array_append_vals(file_type_extensions_arr, wireshark_file_type_extensions_base, N_WIRESHARK_FILE_TYPE_EXTENSIONS);
+	} else {
+		g_array_append_vals(file_type_extensions_arr, stratoshark_file_type_extensions_base, N_STRATOSHARK_FILE_TYPE_EXTENSIONS);
+	}
 
 	file_type_extensions = (struct file_extension_info*)(void *)file_type_extensions_arr->data;
 }
@@ -281,7 +303,7 @@ wtap_get_file_extension_type_extensions(unsigned extension_type)
 
 	g_slist_free(compression_type_extensions);
 
-	return extensions;
+	return g_slist_reverse(extensions);
 }
 
 /*
@@ -357,6 +379,7 @@ static const struct open_info open_info_base[] = {
 	{ "Gammu DCT3 trace",                       OPEN_INFO_MAGIC,     dct3trace_open,           NULL,       NULL, NULL },
 	{ "BLF Logfile",                            OPEN_INFO_MAGIC,     blf_open,                 NULL,     NULL, NULL },
 	{ "AUTOSAR DLT Logfile",                    OPEN_INFO_MAGIC,     autosar_dlt_open,         NULL,     NULL, NULL },
+	{ "TTL Logfile",                            OPEN_INFO_MAGIC,     ttl_open,                 NULL,     NULL, NULL },
 	{ "RTPDump files",                          OPEN_INFO_MAGIC,     rtpdump_open,             NULL, NULL, NULL },
 	{ "MIME Files Format",                      OPEN_INFO_MAGIC,     mime_file_open,           NULL,       NULL, NULL },
 	{ "Micropross mplog",                       OPEN_INFO_MAGIC,     mplog_open,               NULL,   NULL, NULL },
@@ -411,6 +434,7 @@ static const struct open_info open_info_base[] = {
 	{ "CSS Electronics CLX000 CAN log",         OPEN_INFO_MAGIC,     cllog_open,               "txt",      NULL, NULL },
 	{ "Ericsson eNode-B raw log",               OPEN_INFO_MAGIC,     eri_enb_log_open,         NULL,       NULL, NULL },
 	{ "Systemd Journal",                        OPEN_INFO_HEURISTIC, systemd_journal_open,     "log;jnl;journal",      NULL, NULL },
+	{ "PEAK CAN TRC log",                       OPEN_INFO_HEURISTIC, peak_trc_open,            "trc",      NULL, NULL },
 
 	/* ASCII trace files from Telnet sessions. */
 	{ "Lucent/Ascend access server trace",      OPEN_INFO_HEURISTIC, ascend_open,              "txt",      NULL, NULL },
@@ -421,11 +445,12 @@ static const struct open_info open_info_base[] = {
 	/* Extremely weak heuristics - put them at the end. */
 	{ "Ixia IxVeriWave .vwr Raw Capture",       OPEN_INFO_HEURISTIC, vwr_open,                 "vwr",      NULL, NULL },
 	{ "CAM Inspector file",                     OPEN_INFO_HEURISTIC, camins_open,              "camins",   NULL, NULL },
+	/* NetLog needs to be before JSON open because it is a specifically formatted JSON file */
+	{ "NetLog",                                 OPEN_INFO_HEURISTIC, netlog_open,              "json",     NULL, NULL },
 	{ "JavaScript Object Notation",             OPEN_INFO_HEURISTIC, json_open,                "json",     NULL, NULL },
 	{ "Ruby Marshal Object",                    OPEN_INFO_HEURISTIC, ruby_marshal_open,        "",         NULL, NULL },
 	{ "3gpp phone log",                         OPEN_INFO_MAGIC,     log3gpp_open,             "log",      NULL, NULL },
 	{ "MP4 media file",                         OPEN_INFO_MAGIC,     mp4_open,                 "mp4",      NULL, NULL },
-
 };
 
 /* this is only used to build the dynamic array on load, do NOT use this
@@ -1980,7 +2005,7 @@ wtap_get_file_extensions_list(int file_type_subtype, bool include_compressed)
 
 	g_slist_free(compression_type_extensions);
 
-	return extensions;
+	return g_slist_reverse(extensions);
 }
 
 /* Return a list of all extensions that are used by all capture file
@@ -2035,7 +2060,7 @@ wtap_get_all_capture_file_extensions_list(void)
 
 	g_slist_free(compression_type_extensions);
 
-	return extensions;
+	return g_slist_reverse(extensions);
 }
 
 /* Return a list of all extensions that are used by all file types that
@@ -2073,7 +2098,7 @@ wtap_get_all_file_extensions_list(void)
 
 	g_slist_free(compression_type_extensions);
 
-	return extensions;
+	return g_slist_reverse(extensions);
 }
 
 /*
@@ -2125,7 +2150,7 @@ wtap_dump_can_open(int file_type_subtype)
  * Return whether we know how to write a compressed file of the specified
  * file type.
  */
-#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG) || defined (HAVE_LZ4FRAME_H)
 bool
 wtap_dump_can_compress(int file_type_subtype)
 {
@@ -2152,9 +2177,10 @@ wtap_dump_can_compress(int file_type_subtype _U_)
 static bool wtap_dump_open_finish(wtap_dumper *wdh, int *err,
 				      char **err_info);
 
-static WFILE_T wtap_dump_file_open(wtap_dumper *wdh, const char *filename);
-static WFILE_T wtap_dump_file_fdopen(wtap_dumper *wdh, int fd);
+static WFILE_T wtap_dump_file_open(const wtap_dumper *wdh, const char *filename);
+static WFILE_T wtap_dump_file_fdopen(const wtap_dumper *wdh, int fd);
 static int wtap_dump_file_close(wtap_dumper *wdh);
+static bool wtap_dump_fix_idb(wtap_dumper *wdh, wtap_block_t idb, int *err);
 
 static wtap_dumper *
 wtap_dump_init_dumper(int file_type_subtype, wtap_compression_type compression_type,
@@ -2175,7 +2201,7 @@ wtap_dump_init_dumper(int file_type_subtype, wtap_compression_type compression_t
 	if (!wtap_dump_can_open(file_type_subtype)) {
 		/* Invalid type, or type we don't know how to write. */
 		*err = WTAP_ERR_UNWRITABLE_FILE_TYPE;
-		return false;
+		return NULL;
 	}
 
 	/* OK, we know how to write that file type/subtype; can we write
@@ -2247,6 +2273,9 @@ wtap_dump_init_dumper(int file_type_subtype, wtap_compression_type compression_t
 					descr_mand = (wtapng_if_descr_mandatory_t*)wtap_block_get_mandatory_data(descr);
 					descr_mand->wtap_encap = params->encap;
 				}
+				if (!wtap_dump_fix_idb(wdh, descr, err)) {
+					return NULL;
+				}
 				g_array_append_val(wdh->interface_data, descr);
 			}
 		}
@@ -2272,6 +2301,8 @@ wtap_dump_init_dumper(int file_type_subtype, wtap_compression_type compression_t
 	wdh->dsbs_growing = params->dsbs_growing;
 	/* Set Sysdig meta events */
 	wdh->mevs_growing = params->mevs_growing;
+	/* Set DPIBs */
+	wdh->dpibs_growing = params->dpibs_growing;
 	return wdh;
 }
 
@@ -2496,42 +2527,115 @@ wtap_dump_open_finish(wtap_dumper *wdh, int *err, char **err_info)
 	return true;	/* success! */
 }
 
+/* XXX - Temporary hack to deal with nstime_t, and thus wtap_rec and libwiretap
+ * in general, not storing precision greater than nanoseconds yet. Despite
+ * whatever precision an IDB claims, we can't write finer than nanosecond.
+ * Eventually this should be removed.
+ * Fix a given IDB to indicate no greater than nanosecond precision. */
+static bool
+wtap_dump_fix_idb(wtap_dumper *wdb _U_, wtap_block_t idb, int *err)
+{
+	wtapng_if_descr_mandatory_t *idb_mand;
+	int64_t tsoffset;
+	idb_mand = (wtapng_if_descr_mandatory_t*)wtap_block_get_mandatory_data(idb);
+
+	/*
+	 * nstime_t only stores nanoseconds, so instead of claiming false
+	 * precision, fix things up.
+	 */
+	if (idb_mand->time_units_per_second > 1000000000) {
+		ws_warning("original time precision reduced to nanoseconds");
+		idb_mand->time_units_per_second = 1000000000;
+		switch (wtap_block_set_uint8_option_value(idb, OPT_IDB_TSRESOL, 9)) {
+		case WTAP_OPTTYPE_SUCCESS:
+			break;
+		case WTAP_OPTTYPE_NOT_FOUND:
+			// This "should not" happen, because no if_tsresol means 6,
+			// and time_units_per_second should be 1000000;
+			if (wtap_block_add_uint8_option(idb, OPT_IDB_TSRESOL, 9) == WTAP_OPTTYPE_SUCCESS) {
+				break;
+			}
+			/* FALLTHROUGH */
+		default:
+			// These "should not" happen either.
+			*err = WTAP_ERR_INTERNAL;
+			return false;
+		}
+	}
+
+	/*
+	 * Since we're not writing more than nanosecond resolution, if_tsoffset
+	 * isn't necessary, as anything we can store in absolute timestamps in
+	 * Wireshark records we can write to a file without an offset (unless
+	 * we have 32-bit time_t, but that's rare these days.) So we remove it
+	 * here, though in the long term we should keep it.
+	 */
+	if (wtap_block_get_int64_option_value(idb, OPT_IDB_TSOFFSET, &tsoffset) == WTAP_OPTTYPE_SUCCESS) {
+		wtap_block_remove_option(idb, OPT_IDB_TSOFFSET);
+	}
+
+	return true;
+}
+
 bool
 wtap_dump_add_idb(wtap_dumper *wdh, wtap_block_t idb, int *err,
                   char **err_info)
 {
+	wtap_block_t idb_copy;
+
 	if (wdh->subtype_add_idb == NULL) {
 		/* Not supported. */
 		*err = WTAP_ERR_UNWRITABLE_REC_TYPE;
 		*err_info = g_strdup("Adding IDBs isn't supported by this file type");
 		return false;
 	}
+
+	/*
+	 * Add a copy of this IDB to our array of IDBs.
+	 */
+	idb_copy = wtap_block_create(WTAP_BLOCK_IF_ID_AND_INFO);
+	wtap_block_copy(idb_copy, idb);
+	g_array_append_val(wdh->interface_data, idb_copy);
+
+	if (!wtap_dump_fix_idb(wdh, idb_copy, err)) {
+		*err_info = ws_strdup_printf("pcapng: failed to lower time resolution to nanoseconds");
+		return false;
+	}
+
 	*err = 0;
 	*err_info = NULL;
 	return (wdh->subtype_add_idb)(wdh, idb, err, err_info);
 }
 
 bool
-wtap_dump(wtap_dumper *wdh, const wtap_rec *rec,
-	  const uint8_t *pd, int *err, char **err_info)
+wtap_dump(wtap_dumper *wdh, const wtap_rec *rec, int *err, char **err_info)
 {
 	*err = 0;
 	*err_info = NULL;
-	return (wdh->subtype_write)(wdh, rec, pd, err, err_info);
+	return (wdh->subtype_write)(wdh, rec, err, err_info);
 }
 
 bool
 wtap_dump_flush(wtap_dumper *wdh, int *err)
 {
+	switch (wdh->compression_type) {
 #if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
-	if (wdh->compression_type == WTAP_GZIP_COMPRESSED) {
+	case WTAP_GZIP_COMPRESSED:
 		if (gzwfile_flush((GZWFILE_T)wdh->fh) == -1) {
 			*err = gzwfile_geterr((GZWFILE_T)wdh->fh);
 			return false;
 		}
-	} else
+		break;
 #endif
-	{
+#ifdef HAVE_LZ4FRAME_H
+	case WTAP_LZ4_COMPRESSED:
+		if (lz4wfile_flush((LZ4WFILE_T)wdh->fh) == -1) {
+			*err = lz4wfile_geterr((LZ4WFILE_T)wdh->fh);
+			return false;
+		}
+		break;
+#endif /* HAVE_LZ4FRAME_H */
+	default:
 		if (fflush((FILE *)wdh->fh) == EOF) {
 			*err = errno;
 			return false;
@@ -2574,13 +2678,13 @@ wtap_dump_close(wtap_dumper *wdh, bool *needs_reload,
 }
 
 int
-wtap_dump_file_type_subtype(wtap_dumper *wdh)
+wtap_dump_file_type_subtype(const wtap_dumper *wdh)
 {
 	return wdh->file_type_subtype;
 }
 
 int64_t
-wtap_get_bytes_dumped(wtap_dumper *wdh)
+wtap_get_bytes_dumped(const wtap_dumper *wdh)
 {
 	return wdh->bytes_dumped;
 }
@@ -2592,7 +2696,7 @@ wtap_set_bytes_dumped(wtap_dumper *wdh, int64_t bytes_dumped)
 }
 
 bool
-wtap_addrinfo_list_empty(addrinfo_lists_t *addrinfo_lists)
+wtap_addrinfo_list_empty(const addrinfo_lists_t *addrinfo_lists)
 {
 	return (addrinfo_lists == NULL) ||
 	    ((addrinfo_lists->ipv4_addr_list == NULL) &&
@@ -2657,42 +2761,40 @@ wtap_dump_discard_sysdig_meta_events(wtap_dumper *wdh)
 }
 
 /* internally open a file for writing (compressed or not) */
-#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
 static WFILE_T
-wtap_dump_file_open(wtap_dumper *wdh, const char *filename)
+wtap_dump_file_open(const wtap_dumper *wdh, const char *filename)
 {
-	if (wdh->compression_type == WTAP_GZIP_COMPRESSED) {
+	switch (wdh->compression_type) {
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+	case WTAP_GZIP_COMPRESSED:
 		return gzwfile_open(filename);
-	} else {
+#endif /* defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG) */
+#ifdef HAVE_LZ4FRAME_H
+	case WTAP_LZ4_COMPRESSED:
+		return lz4wfile_open(filename);
+#endif /* HAVE_LZ4FRAME_H */
+	default:
 		return ws_fopen(filename, "wb");
 	}
 }
-#else
-static WFILE_T
-wtap_dump_file_open(wtap_dumper *wdh _U_, const char *filename)
-{
-	return ws_fopen(filename, "wb");
-}
-#endif
 
 /* internally open a file for writing (compressed or not) */
-#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
 static WFILE_T
-wtap_dump_file_fdopen(wtap_dumper *wdh, int fd)
+wtap_dump_file_fdopen(const wtap_dumper *wdh, int fd)
 {
-	if (wdh->compression_type == WTAP_GZIP_COMPRESSED) {
+	switch (wdh->compression_type) {
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+	case WTAP_GZIP_COMPRESSED:
 		return gzwfile_fdopen(fd);
-	} else {
+#endif /* defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG) */
+#ifdef HAVE_LZ4FRAME_H
+	case WTAP_LZ4_COMPRESSED:
+		return lz4wfile_fdopen(fd);
+#endif /* HAVE_LZ4FRAME_H */
+	default:
 		return ws_fdopen(fd, "wb");
 	}
 }
-#else
-static WFILE_T
-wtap_dump_file_fdopen(wtap_dumper *wdh _U_, int fd)
-{
-	return ws_fdopen(fd, "wb");
-}
-#endif
 
 /* internally writing raw bytes (compressed or not). Updates wdh->bytes_dumped on success */
 bool
@@ -2700,8 +2802,9 @@ wtap_dump_file_write(wtap_dumper *wdh, const void *buf, size_t bufsize, int *err
 {
 	size_t nwritten;
 
+	switch (wdh->compression_type) {
 #if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
-	if (wdh->compression_type == WTAP_GZIP_COMPRESSED) {
+	case WTAP_GZIP_COMPRESSED:
 		nwritten = gzwfile_write((GZWFILE_T)wdh->fh, buf, (unsigned int) bufsize);
 		/*
 		 * gzwfile_write() returns 0 on error.
@@ -2710,9 +2813,21 @@ wtap_dump_file_write(wtap_dumper *wdh, const void *buf, size_t bufsize, int *err
 			*err = gzwfile_geterr((GZWFILE_T)wdh->fh);
 			return false;
 		}
-	} else
+		break;
 #endif
-	{
+#ifdef HAVE_LZ4FRAME_H
+	case WTAP_LZ4_COMPRESSED:
+		nwritten = lz4wfile_write((LZ4WFILE_T)wdh->fh, buf, bufsize);
+		/*
+		 * lz4wfile_write() returns 0 on error.
+		 */
+		if (nwritten == 0) {
+			*err = lz4wfile_geterr((LZ4WFILE_T)wdh->fh);
+			return false;
+		}
+		break;
+#endif /* HAVE_LZ4FRAME_H */
+	default:
 		errno = WTAP_ERR_CANT_WRITE;
 		nwritten = fwrite(buf, 1, bufsize, (FILE *)wdh->fh);
 		/*
@@ -2735,18 +2850,24 @@ wtap_dump_file_write(wtap_dumper *wdh, const void *buf, size_t bufsize, int *err
 static int
 wtap_dump_file_close(wtap_dumper *wdh)
 {
+	switch (wdh->compression_type) {
 #if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
-	if (wdh->compression_type == WTAP_GZIP_COMPRESSED)
+	case WTAP_GZIP_COMPRESSED:
 		return gzwfile_close((GZWFILE_T)wdh->fh);
-	else
 #endif
+#ifdef HAVE_LZ4FRAME_H
+	case WTAP_LZ4_COMPRESSED:
+		return lz4wfile_close((LZ4WFILE_T)wdh->fh);
+#endif /* HAVE_LZ4FRAME_H */
+	default:
 		return fclose((FILE *)wdh->fh);
+	}
 }
 
 int64_t
 wtap_dump_file_seek(wtap_dumper *wdh, int64_t offset, int whence, int *err)
 {
-#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG) || defined (HAVE_LZ4FRAME_H)
 	if (wdh->compression_type != WTAP_UNCOMPRESSED) {
 		*err = WTAP_ERR_CANT_SEEK_COMPRESSED;
 		return -1;
@@ -2767,7 +2888,7 @@ int64_t
 wtap_dump_file_tell(wtap_dumper *wdh, int *err)
 {
 	int64_t rval;
-#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG) || defined (HAVE_LZ4FRAME_H)
 	if (wdh->compression_type != WTAP_UNCOMPRESSED) {
 		*err = WTAP_ERR_CANT_SEEK_COMPRESSED;
 		return -1;
