@@ -11,10 +11,22 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include "wtap-int.h"
+
+#include <wsutil/array.h>
+#include <wsutil/pint.h>
+
+#include "wtap_module.h"
 #include "file_wrappers.h"
 #include "atm.h"
 
+/*
+ * iptrace is the capture program that comes with AIX 3.x and 4.x.  AIX 3 uses
+ * the iptrace 1.0 file format, while AIX4 uses iptrace 2.0.  iptrace has
+ * an undocumented, yet very simple, file format.  The interesting thing
+ * about iptrace is that it will record packets coming in from all network
+ * interfaces; a single iptrace file can contain multiple datalink types.
+*/
+
 /*
  * Private per-wtap_t data needed to read a file.
  */
@@ -29,16 +41,16 @@ typedef struct {
 static void iptrace_close(wtap *wth);
 
 static bool iptrace_read_1_0(wtap *wth, wtap_rec *rec,
-    Buffer *buf, int *err, char **err_info, int64_t *data_offset);
+    int *err, char **err_info, int64_t *data_offset);
 static bool iptrace_seek_read_1_0(wtap *wth, int64_t seek_off,
-    wtap_rec *rec, Buffer *buf, int *err, char **err_info);
+    wtap_rec *rec, int *err, char **err_info);
 
 static bool iptrace_read_2_0(wtap *wth, wtap_rec *rec,
-    Buffer *buf, int *err, char **err_info, int64_t *data_offset);
+    int *err, char **err_info, int64_t *data_offset);
 static bool iptrace_seek_read_2_0(wtap *wth, int64_t seek_off,
-    wtap_rec *rec, Buffer *buf, int *err, char **err_info);
+    wtap_rec *rec, int *err, char **err_info);
 
-static bool iptrace_read_rec_data(FILE_T fh, Buffer *buf,
+static bool iptrace_read_rec_data(FILE_T fh,
     wtap_rec *rec, int *err, char **err_info);
 static void fill_in_pseudo_header(int encap,
     union wtap_pseudo_header *pseudo_header, const char *pkt_text);
@@ -193,7 +205,7 @@ static void add_new_if_info(iptrace_t *iptrace, if_info *info, void * *result)
 #define IPTRACE_1_0_PINFO_SIZE	22	/* packet information */
 
 static bool
-iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
+iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec,
     int *err, char **err_info)
 {
 	iptrace_t		*iptrace = (iptrace_t *)wth->priv;
@@ -211,7 +223,7 @@ iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 	}
 
 	/* Get the record length */
-	record_length = pntoh32(&header[IPTRACE_1_0_REC_LENGTH_OFFSET]);
+	record_length = pntohu32(&header[IPTRACE_1_0_REC_LENGTH_OFFSET]);
 	if (record_length < IPTRACE_1_0_PINFO_SIZE) {
 		/*
 		 * Uh-oh, the record isn't big enough to even have a
@@ -232,6 +244,9 @@ iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 		return false;
 	}
 
+	wtap_setup_packet_rec(rec, wth->file_encap);
+	rec->block = wtap_block_create(WTAP_BLOCK_PACKET);
+
 	/*
 	 * The if_type field of the frame header appears to be an SNMP
 	 * ifType value giving the type of the interface.  Check out the
@@ -287,12 +302,10 @@ iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 		return false;
 	}
 
-	rec->rec_type = REC_TYPE_PACKET;
-	rec->block = wtap_block_create(WTAP_BLOCK_PACKET);
 	rec->presence_flags = WTAP_HAS_TS | WTAP_HAS_INTERFACE_ID;
 	rec->rec_header.packet_header.len = packet_size;
 	rec->rec_header.packet_header.caplen = packet_size;
-	rec->ts.secs = pntoh32(&header[IPTRACE_1_0_TV_SEC_OFFSET]);
+	rec->ts.secs = pntohu32(&header[IPTRACE_1_0_TV_SEC_OFFSET]);
 	rec->ts.nsecs = 0;
 	wtap_block_add_uint32_option(rec->block, OPT_PKT_FLAGS,
 	    pkt_info[IPTRACE_1_0_TX_FLAGS_OFFSET] ?
@@ -305,7 +318,7 @@ iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 	    (const char *)&pkt_info[IPTRACE_1_0_PKT_TEXT_OFFSET]);
 
 	/* Get the packet data */
-	if (!iptrace_read_rec_data(fh, buf, rec, err, err_info))
+	if (!iptrace_read_rec_data(fh, rec, err, err_info))
 		return false;
 
 	/*
@@ -358,12 +371,12 @@ iptrace_read_rec_1_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 
 /* Read the next packet */
 static bool iptrace_read_1_0(wtap *wth, wtap_rec *rec,
-    Buffer *buf, int *err, char **err_info, int64_t *data_offset)
+    int *err, char **err_info, int64_t *data_offset)
 {
 	*data_offset = file_tell(wth->fh);
 
 	/* Read the packet */
-	if (!iptrace_read_rec_1_0(wth, wth->fh, rec, buf, err, err_info)) {
+	if (!iptrace_read_rec_1_0(wth, wth->fh, rec, err, err_info)) {
 		/* Read error or EOF */
 		return false;
 	}
@@ -385,13 +398,13 @@ static bool iptrace_read_1_0(wtap *wth, wtap_rec *rec,
 }
 
 static bool iptrace_seek_read_1_0(wtap *wth, int64_t seek_off,
-    wtap_rec *rec, Buffer *buf, int *err, char **err_info)
+    wtap_rec *rec, int *err, char **err_info)
 {
 	if (file_seek(wth->random_fh, seek_off, SEEK_SET, err) == -1)
 		return false;
 
 	/* Read the packet */
-	if (!iptrace_read_rec_1_0(wth, wth->random_fh, rec, buf, err,
+	if (!iptrace_read_rec_1_0(wth, wth->random_fh, rec, err,
 	    err_info)) {
 		if (*err == 0)
 			*err = WTAP_ERR_SHORT_READ;
@@ -447,7 +460,7 @@ static bool iptrace_seek_read_1_0(wtap *wth, int64_t seek_off,
 #define IPTRACE_2_0_PINFO_SIZE	32	/* packet information */
 
 static bool
-iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
+iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec,
     int *err, char **err_info)
 {
 	iptrace_t		*iptrace = (iptrace_t *)wth->priv;
@@ -465,7 +478,7 @@ iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 	}
 
 	/* Get the record length */
-	record_length = pntoh32(&header[IPTRACE_2_0_REC_LENGTH_OFFSET]);
+	record_length = pntohu32(&header[IPTRACE_2_0_REC_LENGTH_OFFSET]);
 	if (record_length < IPTRACE_2_0_PINFO_SIZE) {
 		/*
 		 * Uh-oh, the record isn't big enough to even have a
@@ -486,6 +499,9 @@ iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 		return false;
 	}
 
+	wtap_setup_packet_rec(rec, wth->file_encap);
+	rec->block = wtap_block_create(WTAP_BLOCK_PACKET);
+
 	/*
 	 * The if_type field of the frame header appears to be an SNMP
 	 * ifType value giving the type of the interface.  Check out the
@@ -559,13 +575,11 @@ iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 		return false;
 	}
 
-	rec->rec_type = REC_TYPE_PACKET;
-	rec->block = wtap_block_create(WTAP_BLOCK_PACKET);
 	rec->presence_flags = WTAP_HAS_TS | WTAP_HAS_INTERFACE_ID;
 	rec->rec_header.packet_header.len = packet_size;
 	rec->rec_header.packet_header.caplen = packet_size;
-	rec->ts.secs = pntoh32(&pkt_info[IPTRACE_2_0_TV_SEC_OFFSET]);
-	rec->ts.nsecs = pntoh32(&pkt_info[IPTRACE_2_0_TV_NSEC_OFFSET]);
+	rec->ts.secs = pntohu32(&pkt_info[IPTRACE_2_0_TV_SEC_OFFSET]);
+	rec->ts.nsecs = pntohu32(&pkt_info[IPTRACE_2_0_TV_NSEC_OFFSET]);
 	wtap_block_add_uint32_option(rec->block, OPT_PKT_FLAGS,
 	    pkt_info[IPTRACE_2_0_TX_FLAGS_OFFSET] ?
 	      (PACK_FLAGS_DIRECTION_OUTBOUND << PACK_FLAGS_DIRECTION_SHIFT) :
@@ -577,7 +591,7 @@ iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 	    (const char *)&pkt_info[IPTRACE_1_0_PKT_TEXT_OFFSET]);
 
 	/* Get the packet data */
-	if (!iptrace_read_rec_data(fh, buf, rec, err, err_info))
+	if (!iptrace_read_rec_data(fh, rec, err, err_info))
 		return false;
 
 	/*
@@ -630,12 +644,12 @@ iptrace_read_rec_2_0(wtap *wth, FILE_T fh, wtap_rec *rec, Buffer *buf,
 
 /* Read the next packet */
 static bool iptrace_read_2_0(wtap *wth, wtap_rec *rec,
-    Buffer *buf, int *err, char **err_info, int64_t *data_offset)
+    int *err, char **err_info, int64_t *data_offset)
 {
 	*data_offset = file_tell(wth->fh);
 
 	/* Read the packet */
-	if (!iptrace_read_rec_2_0(wth, wth->fh, rec, buf, err, err_info)) {
+	if (!iptrace_read_rec_2_0(wth, wth->fh, rec, err, err_info)) {
 		/* Read error or EOF */
 		return false;
 	}
@@ -657,13 +671,13 @@ static bool iptrace_read_2_0(wtap *wth, wtap_rec *rec,
 }
 
 static bool iptrace_seek_read_2_0(wtap *wth, int64_t seek_off,
-    wtap_rec *rec, Buffer *buf, int *err, char **err_info)
+    wtap_rec *rec, int *err, char **err_info)
 {
 	if (file_seek(wth->random_fh, seek_off, SEEK_SET, err) == -1)
 		return false;
 
 	/* Read the packet */
-	if (!iptrace_read_rec_2_0(wth, wth->random_fh, rec, buf, err,
+	if (!iptrace_read_rec_2_0(wth, wth->random_fh, rec, err,
 	    err_info)) {
 		if (*err == 0)
 			*err = WTAP_ERR_SHORT_READ;
@@ -673,10 +687,9 @@ static bool iptrace_seek_read_2_0(wtap *wth, int64_t seek_off,
 }
 
 static bool
-iptrace_read_rec_data(FILE_T fh, Buffer *buf, wtap_rec *rec,
-    int *err, char **err_info)
+iptrace_read_rec_data(FILE_T fh, wtap_rec *rec, int *err, char **err_info)
 {
-	if (!wtap_read_packet_bytes(fh, buf, rec->rec_header.packet_header.caplen, err, err_info))
+	if (!wtap_read_bytes_buffer(fh, &rec->data, rec->rec_header.packet_header.caplen, err, err_info))
 		return false;
 
 	if (rec->rec_header.packet_header.pkt_encap == WTAP_ENCAP_ATM_PDUS) {
@@ -684,7 +697,7 @@ iptrace_read_rec_data(FILE_T fh, Buffer *buf, wtap_rec *rec,
 		 * Attempt to guess from the packet data, the VPI,
 		 * and the VCI information about the type of traffic.
 		 */
-		atm_guess_traffic_type(rec, ws_buffer_start_ptr(buf));
+		atm_guess_traffic_type(rec);
 	}
 
 	return true;
@@ -811,7 +824,6 @@ wtap_encap_ift(unsigned int  ift)
 			/* Infiniband*/
 			case IPTRACE_IFT_IB:
 				return WTAP_ENCAP_INFINIBAND;
-				break;
 
 			/* Host Fabric Interface */
 			case IPTRACE_IFT_HF:
@@ -825,7 +837,6 @@ wtap_encap_ift(unsigned int  ift)
 				have to figure out which field in the iptrace file
 				encodes it. */
 				return WTAP_ENCAP_RAW_IP;
-				break;
 
 			default:
 				return WTAP_ENCAP_UNKNOWN;
