@@ -30,19 +30,14 @@ typedef struct _plugin {
     GModule        *handle;       /* handle returned by g_module_open */
     char           *name;         /* plugin name */
     const char     *version;      /* plugin version */
-    const char     *type_name;    /* user-facing name (what it does). Should these be capitalized? */
+    uint32_t        flags;        /* plugin flags */
 } plugin;
 
 #define TYPE_DIR_EPAN       "epan"
 #define TYPE_DIR_WIRETAP    "wiretap"
 #define TYPE_DIR_CODECS     "codecs"
 
-#define TYPE_NAME_DISSECTOR "dissector"
-#define TYPE_NAME_FILE_TYPE "file type"
-#define TYPE_NAME_CODEC     "codec"
-
-
-static GSList *plugins_module_list = NULL;
+static GSList *plugins_module_list;
 
 
 static inline const char *
@@ -63,20 +58,24 @@ type_to_dir(plugin_type_e type)
 }
 
 static inline const char *
-type_to_name(plugin_type_e type)
+flags_to_str(uint32_t flags)
 {
-    switch (type) {
-    case WS_PLUGIN_EPAN:
-        return TYPE_NAME_DISSECTOR;
-    case WS_PLUGIN_WIRETAP:
-        return TYPE_NAME_FILE_TYPE;
-    case WS_PLUGIN_CODEC:
-        return TYPE_NAME_CODEC;
-    default:
-        ws_error("Unknown plugin type: %u. Aborting.", (unsigned) type);
-        break;
-    }
-    ws_assert_not_reached();
+    /* XXX: Allow joining multiple types? Our plugins only implement a
+     * single type but out in the wild this may not be true. */
+    if (flags & WS_PLUGIN_DESC_DISSECTOR)
+        return "dissector";
+    else if (flags & WS_PLUGIN_DESC_FILE_TYPE)
+        return "file type";
+    else if (flags & WS_PLUGIN_DESC_CODEC)
+        return "codec";
+    else if (flags & WS_PLUGIN_DESC_EPAN)
+        return "epan";
+    else if (flags & WS_PLUGIN_DESC_TAP_LISTENER)
+        return "tap listener";
+    else if (flags & WS_PLUGIN_DESC_DFILTER)
+        return "dfilter";
+    else
+        return "unknown";
 }
 
 static void
@@ -89,7 +88,7 @@ free_plugin(void * data)
 }
 
 static int
-compare_plugins(gconstpointer a, gconstpointer b)
+compare_plugins(const void *a, const void *b)
 {
     return g_strcmp0((*(plugin *const *)a)->name, (*(plugin *const *)b)->name);
 }
@@ -138,6 +137,7 @@ scan_plugins_dir(GHashTable *plugins_module, const char *dirpath, plugin_type_e
     GModule       *handle;          /* handle returned by g_module_open */
     void *         symbol;
     const char    *plug_version;
+    uint32_t       flags;
     plugin        *new_plug;
 
     if (append_type)
@@ -206,16 +206,27 @@ DIAG_OFF_PEDANTIC
         ((plugin_register_func)symbol)();
 DIAG_ON_PEDANTIC
 
+        /* Search for the (optional) description flag registration function */
+        if (g_module_symbol(handle, "plugin_describe", &symbol))
+            flags = ((plugin_describe_func)symbol)();
+        else
+            flags = 0;
+
         new_plug = g_new(plugin, 1);
         new_plug->handle = handle;
         new_plug->name = g_strdup(name);
         new_plug->version = plug_version;
-        new_plug->type_name = type_to_name(type);
+        new_plug->flags = flags;
 
         /* Add it to the list of plugins. */
         g_hash_table_replace(plugins_module, new_plug->name, new_plug);
         ws_info("Registered plugin: %s (%s)", new_plug->name, plugin_file);
         g_free(plugin_file);
+#if defined (ENABLE_ASAN) || defined (ENABLE_LSAN)
+        // XXX - Look for valgrind.h so we can also check RUNNING_ON_VALGRIND?
+        // https://valgrind.org/docs/manual/manual-core-adv.html
+        g_module_make_resident(handle);
+#endif
     }
     ws_dir_close(dir);
     g_free(plugin_folder);
@@ -245,7 +256,7 @@ plugins_init(plugin_type_e type)
      * if we need privileges to start capturing, we'd need to
      * reclaim them before each time we start capturing.)
      */
-    if (!started_with_special_privs()) {
+    if (!started_with_special_privs() && !files_identical(get_plugins_dir_with_version(), get_plugins_pers_dir_with_version())) {
         scan_plugins_dir(plugins_module, get_plugins_pers_dir_with_version(), type, true);
     }
 
@@ -272,7 +283,7 @@ plugins_get_descriptions(plugin_description_callback callback, void *callback_da
 
     for (unsigned i = 0; i < plugins_array->len; i++) {
         plugin *plug = (plugin *)plugins_array->pdata[i];
-        callback(plug->name, plug->version, plug->type_name, g_module_name(plug->handle), callback_data);
+        callback(plug->name, plug->version, plug->flags, g_module_name(plug->handle), callback_data);
     }
 
     g_ptr_array_free(plugins_array, true);
@@ -280,10 +291,10 @@ plugins_get_descriptions(plugin_description_callback callback, void *callback_da
 
 static void
 print_plugin_description(const char *name, const char *version,
-                         const char *description, const char *filename,
+                         uint32_t flags, const char *filename,
                          void *user_data _U_)
 {
-    printf("%-16s\t%s\t%s\t%s\n", name, version, description, filename);
+    printf("%-16s\t%s\t%s\t%s\n", name, version, flags_to_str(flags), filename);
 }
 
 void
